# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .accelerator_type import (
    AcceleratorType,
)
from .annotation import (
    Annotation,
)
from .annotation_spec import (
    AnnotationSpec,
)
from .api_auth import (
    ApiAuth,
)
from .artifact import (
    Artifact,
)
from .batch_prediction_job import (
    BatchPredictionJob,
)
from .cached_content import (
    CachedContent,
)
from .completion_stats import (
    CompletionStats,
)
from .content import (
    Blob,
    Candidate,
    Citation,
    CitationMetadata,
    Content,
    FileData,
    GenerationConfig,
    GroundingChunk,
    GroundingMetadata,
    GroundingSupport,
    ImageConfig,
    LogprobsResult,
    ModalityTokenCount,
    ModelArmorConfig,
    MultiSpeakerVoiceConfig,
    Part,
    PrebuiltVoiceConfig,
    ReplicatedVoiceConfig,
    RetrievalMetadata,
    SafetyRating,
    SafetySetting,
    SearchEntryPoint,
    Segment,
    SpeakerVoiceConfig,
    SpeechConfig,
    UrlContextMetadata,
    UrlMetadata,
    VideoMetadata,
    VoiceConfig,
    HarmCategory,
    Modality,
)
from .context import (
    Context,
)
from .custom_job import (
    ContainerSpec,
    CustomJob,
    CustomJobSpec,
    PythonPackageSpec,
    Scheduling,
    WorkerPoolSpec,
)
from .data_item import (
    DataItem,
)
from .data_labeling_job import (
    ActiveLearningConfig,
    DataLabelingJob,
    SampleConfig,
    TrainingConfig,
)
from .dataset import (
    Dataset,
    ExportDataConfig,
    ExportFractionSplit,
    ImportDataConfig,
)
from .dataset_service import (
    AssembleDataOperationMetadata,
    AssembleDataRequest,
    AssembleDataResponse,
    AssessDataOperationMetadata,
    AssessDataRequest,
    AssessDataResponse,
    CreateDatasetOperationMetadata,
    CreateDatasetRequest,
    CreateDatasetVersionOperationMetadata,
    CreateDatasetVersionRequest,
    DataItemView,
    DeleteDatasetRequest,
    DeleteDatasetVersionRequest,
    DeleteSavedQueryRequest,
    ExportDataOperationMetadata,
    ExportDataRequest,
    ExportDataResponse,
    GeminiExample,
    GeminiRequestReadConfig,
    GeminiTemplateConfig,
    GetAnnotationSpecRequest,
    GetDatasetRequest,
    GetDatasetVersionRequest,
    ImportDataOperationMetadata,
    ImportDataRequest,
    ImportDataResponse,
    ListAnnotationsRequest,
    ListAnnotationsResponse,
    ListDataItemsRequest,
    ListDataItemsResponse,
    ListDatasetsRequest,
    ListDatasetsResponse,
    ListDatasetVersionsRequest,
    ListDatasetVersionsResponse,
    ListSavedQueriesRequest,
    ListSavedQueriesResponse,
    RestoreDatasetVersionOperationMetadata,
    RestoreDatasetVersionRequest,
    SearchDataItemsRequest,
    SearchDataItemsResponse,
    UpdateDatasetRequest,
    UpdateDatasetVersionRequest,
)
from .dataset_version import (
    DatasetVersion,
)
from .deployed_index_ref import (
    DeployedIndexRef,
)
from .deployed_model_ref import (
    DeployedModelRef,
)
from .deployment_resource_pool import (
    DeploymentResourcePool,
)
from .deployment_resource_pool_service import (
    CreateDeploymentResourcePoolOperationMetadata,
    CreateDeploymentResourcePoolRequest,
    DeleteDeploymentResourcePoolRequest,
    GetDeploymentResourcePoolRequest,
    ListDeploymentResourcePoolsRequest,
    ListDeploymentResourcePoolsResponse,
    QueryDeployedModelsRequest,
    QueryDeployedModelsResponse,
    UpdateDeploymentResourcePoolOperationMetadata,
    UpdateDeploymentResourcePoolRequest,
)
from .deployment_stage import (
    DeploymentStage,
)
from .encryption_spec import (
    EncryptionSpec,
)
from .endpoint import (
    ClientConnectionConfig,
    DeployedModel,
    Endpoint,
    FasterDeploymentConfig,
    GenAiAdvancedFeaturesConfig,
    PredictRequestResponseLoggingConfig,
    PrivateEndpoints,
    PublisherModelConfig,
    RolloutOptions,
    SpeculativeDecodingSpec,
)
from .endpoint_service import (
    CreateEndpointOperationMetadata,
    CreateEndpointRequest,
    DeleteEndpointRequest,
    DeployModelOperationMetadata,
    DeployModelRequest,
    DeployModelResponse,
    FetchPublisherModelConfigRequest,
    GetEndpointRequest,
    ListEndpointsRequest,
    ListEndpointsResponse,
    MutateDeployedModelOperationMetadata,
    MutateDeployedModelRequest,
    MutateDeployedModelResponse,
    SetPublisherModelConfigOperationMetadata,
    SetPublisherModelConfigRequest,
    UndeployModelOperationMetadata,
    UndeployModelRequest,
    UndeployModelResponse,
    UpdateEndpointLongRunningRequest,
    UpdateEndpointOperationMetadata,
    UpdateEndpointRequest,
)
from .entity_type import (
    EntityType,
)
from .env_var import (
    EnvVar,
    SecretEnvVar,
    SecretRef,
)
from .evaluated_annotation import (
    ErrorAnalysisAnnotation,
    EvaluatedAnnotation,
    EvaluatedAnnotationExplanation,
)
from .evaluation_service import (
    AggregationOutput,
    AggregationResult,
    AutoraterConfig,
    BleuInput,
    BleuInstance,
    BleuMetricValue,
    BleuResults,
    BleuSpec,
    CoherenceInput,
    CoherenceInstance,
    CoherenceResult,
    CoherenceSpec,
    CometInput,
    CometInstance,
    CometResult,
    CometSpec,
    ContentMap,
    CustomOutput,
    CustomOutputFormatConfig,
    EvaluateDatasetOperationMetadata,
    EvaluateDatasetRequest,
    EvaluateDatasetResponse,
    EvaluateInstancesRequest,
    EvaluateInstancesResponse,
    EvaluationDataset,
    ExactMatchInput,
    ExactMatchInstance,
    ExactMatchMetricValue,
    ExactMatchResults,
    ExactMatchSpec,
    FluencyInput,
    FluencyInstance,
    FluencyResult,
    FluencySpec,
    FulfillmentInput,
    FulfillmentInstance,
    FulfillmentResult,
    FulfillmentSpec,
    GroundednessInput,
    GroundednessInstance,
    GroundednessResult,
    GroundednessSpec,
    Metric,
    MetricxInput,
    MetricxInstance,
    MetricxResult,
    MetricxSpec,
    OutputConfig,
    OutputInfo,
    PairwiseMetricInput,
    PairwiseMetricInstance,
    PairwiseMetricResult,
    PairwiseMetricSpec,
    PairwiseQuestionAnsweringQualityInput,
    PairwiseQuestionAnsweringQualityInstance,
    PairwiseQuestionAnsweringQualityResult,
    PairwiseQuestionAnsweringQualitySpec,
    PairwiseSummarizationQualityInput,
    PairwiseSummarizationQualityInstance,
    PairwiseSummarizationQualityResult,
    PairwiseSummarizationQualitySpec,
    PointwiseMetricInput,
    PointwiseMetricInstance,
    PointwiseMetricResult,
    PointwiseMetricSpec,
    QuestionAnsweringCorrectnessInput,
    QuestionAnsweringCorrectnessInstance,
    QuestionAnsweringCorrectnessResult,
    QuestionAnsweringCorrectnessSpec,
    QuestionAnsweringHelpfulnessInput,
    QuestionAnsweringHelpfulnessInstance,
    QuestionAnsweringHelpfulnessResult,
    QuestionAnsweringHelpfulnessSpec,
    QuestionAnsweringQualityInput,
    QuestionAnsweringQualityInstance,
    QuestionAnsweringQualityResult,
    QuestionAnsweringQualitySpec,
    QuestionAnsweringRelevanceInput,
    QuestionAnsweringRelevanceInstance,
    QuestionAnsweringRelevanceResult,
    QuestionAnsweringRelevanceSpec,
    RawOutput,
    RougeInput,
    RougeInstance,
    RougeMetricValue,
    RougeResults,
    RougeSpec,
    RubricBasedInstructionFollowingInput,
    RubricBasedInstructionFollowingInstance,
    RubricBasedInstructionFollowingResult,
    RubricBasedInstructionFollowingSpec,
    RubricCritiqueResult,
    SafetyInput,
    SafetyInstance,
    SafetyResult,
    SafetySpec,
    SummarizationHelpfulnessInput,
    SummarizationHelpfulnessInstance,
    SummarizationHelpfulnessResult,
    SummarizationHelpfulnessSpec,
    SummarizationQualityInput,
    SummarizationQualityInstance,
    SummarizationQualityResult,
    SummarizationQualitySpec,
    SummarizationVerbosityInput,
    SummarizationVerbosityInstance,
    SummarizationVerbosityResult,
    SummarizationVerbositySpec,
    ToolCall,
    ToolCallValidInput,
    ToolCallValidInstance,
    ToolCallValidMetricValue,
    ToolCallValidResults,
    ToolCallValidSpec,
    ToolNameMatchInput,
    ToolNameMatchInstance,
    ToolNameMatchMetricValue,
    ToolNameMatchResults,
    ToolNameMatchSpec,
    ToolParameterKeyMatchInput,
    ToolParameterKeyMatchInstance,
    ToolParameterKeyMatchMetricValue,
    ToolParameterKeyMatchResults,
    ToolParameterKeyMatchSpec,
    ToolParameterKVMatchInput,
    ToolParameterKVMatchInstance,
    ToolParameterKVMatchMetricValue,
    ToolParameterKVMatchResults,
    ToolParameterKVMatchSpec,
    Trajectory,
    TrajectoryAnyOrderMatchInput,
    TrajectoryAnyOrderMatchInstance,
    TrajectoryAnyOrderMatchMetricValue,
    TrajectoryAnyOrderMatchResults,
    TrajectoryAnyOrderMatchSpec,
    TrajectoryExactMatchInput,
    TrajectoryExactMatchInstance,
    TrajectoryExactMatchMetricValue,
    TrajectoryExactMatchResults,
    TrajectoryExactMatchSpec,
    TrajectoryInOrderMatchInput,
    TrajectoryInOrderMatchInstance,
    TrajectoryInOrderMatchMetricValue,
    TrajectoryInOrderMatchResults,
    TrajectoryInOrderMatchSpec,
    TrajectoryPrecisionInput,
    TrajectoryPrecisionInstance,
    TrajectoryPrecisionMetricValue,
    TrajectoryPrecisionResults,
    TrajectoryPrecisionSpec,
    TrajectoryRecallInput,
    TrajectoryRecallInstance,
    TrajectoryRecallMetricValue,
    TrajectoryRecallResults,
    TrajectoryRecallSpec,
    TrajectorySingleToolUseInput,
    TrajectorySingleToolUseInstance,
    TrajectorySingleToolUseMetricValue,
    TrajectorySingleToolUseResults,
    TrajectorySingleToolUseSpec,
    PairwiseChoice,
)
from .event import (
    Event,
)
from .example import (
    ContentsExample,
    StoredContentsExample,
)
from .example_store import (
    ExamplesArrayFilter,
    ExampleStore,
    ExampleStoreConfig,
    StoredContentsExampleFilter,
    StoredContentsExampleParameters,
)
from .example_store_service import (
    CreateExampleStoreOperationMetadata,
    CreateExampleStoreRequest,
    DeleteExampleStoreOperationMetadata,
    DeleteExampleStoreRequest,
    Example,
    FetchExamplesRequest,
    FetchExamplesResponse,
    GetExampleStoreRequest,
    ListExampleStoresRequest,
    ListExampleStoresResponse,
    RemoveExamplesRequest,
    RemoveExamplesResponse,
    SearchExamplesRequest,
    SearchExamplesResponse,
    UpdateExampleStoreOperationMetadata,
    UpdateExampleStoreRequest,
    UpsertExamplesRequest,
    UpsertExamplesResponse,
)
from .execution import (
    Execution,
)
from .explanation import (
    Attribution,
    BlurBaselineConfig,
    Examples,
    ExamplesOverride,
    ExamplesRestrictionsNamespace,
    Explanation,
    ExplanationMetadataOverride,
    ExplanationParameters,
    ExplanationSpec,
    ExplanationSpecOverride,
    FeatureNoiseSigma,
    IntegratedGradientsAttribution,
    ModelExplanation,
    Neighbor,
    Presets,
    SampledShapleyAttribution,
    SmoothGradConfig,
    XraiAttribution,
)
from .explanation_metadata import (
    ExplanationMetadata,
)
from .extension import (
    AuthConfig,
    Extension,
    ExtensionManifest,
    ExtensionOperation,
    ExtensionPrivateServiceConnectConfig,
    RuntimeConfig,
    AuthType,
    HttpElementLocation,
)
from .extension_execution_service import (
    ExecuteExtensionRequest,
    ExecuteExtensionResponse,
    QueryExtensionRequest,
    QueryExtensionResponse,
)
from .extension_registry_service import (
    DeleteExtensionRequest,
    GetExtensionRequest,
    ImportExtensionOperationMetadata,
    ImportExtensionRequest,
    ListExtensionsRequest,
    ListExtensionsResponse,
    UpdateExtensionRequest,
)
from .feature import (
    Feature,
)
from .feature_group import (
    FeatureGroup,
)
from .feature_monitor import (
    FeatureMonitor,
    FeatureSelectionConfig,
    FeatureStatsAndAnomaly,
    FeatureStatsAndAnomalySpec,
    ScheduleConfig,
)
from .feature_monitor_job import (
    FeatureMonitorJob,
)
from .feature_monitoring_stats import (
    FeatureStatsAnomaly,
)
from .feature_online_store import (
    FeatureOnlineStore,
)
from .feature_online_store_admin_service import (
    CreateFeatureOnlineStoreOperationMetadata,
    CreateFeatureOnlineStoreRequest,
    CreateFeatureViewOperationMetadata,
    CreateFeatureViewRequest,
    DeleteFeatureOnlineStoreRequest,
    DeleteFeatureViewRequest,
    GetFeatureOnlineStoreRequest,
    GetFeatureViewRequest,
    GetFeatureViewSyncRequest,
    ListFeatureOnlineStoresRequest,
    ListFeatureOnlineStoresResponse,
    ListFeatureViewsRequest,
    ListFeatureViewsResponse,
    ListFeatureViewSyncsRequest,
    ListFeatureViewSyncsResponse,
    SyncFeatureViewRequest,
    SyncFeatureViewResponse,
    UpdateFeatureOnlineStoreOperationMetadata,
    UpdateFeatureOnlineStoreRequest,
    UpdateFeatureViewOperationMetadata,
    UpdateFeatureViewRequest,
)
from .feature_online_store_service import (
    FeatureViewDataKey,
    FeatureViewDirectWriteRequest,
    FeatureViewDirectWriteResponse,
    FetchFeatureValuesRequest,
    FetchFeatureValuesResponse,
    GenerateFetchAccessTokenRequest,
    GenerateFetchAccessTokenResponse,
    NearestNeighborQuery,
    NearestNeighbors,
    SearchNearestEntitiesRequest,
    SearchNearestEntitiesResponse,
    StreamingFetchFeatureValuesRequest,
    StreamingFetchFeatureValuesResponse,
    FeatureViewDataFormat,
)
from .feature_registry_service import (
    CreateFeatureGroupOperationMetadata,
    CreateFeatureGroupRequest,
    CreateFeatureMonitorJobRequest,
    CreateFeatureMonitorOperationMetadata,
    CreateFeatureMonitorRequest,
    CreateRegistryFeatureOperationMetadata,
    DeleteFeatureGroupRequest,
    DeleteFeatureMonitorRequest,
    GetFeatureGroupRequest,
    GetFeatureMonitorJobRequest,
    GetFeatureMonitorRequest,
    ListFeatureGroupsRequest,
    ListFeatureGroupsResponse,
    ListFeatureMonitorJobsRequest,
    ListFeatureMonitorJobsResponse,
    ListFeatureMonitorsRequest,
    ListFeatureMonitorsResponse,
    UpdateFeatureGroupOperationMetadata,
    UpdateFeatureGroupRequest,
    UpdateFeatureMonitorOperationMetadata,
    UpdateFeatureMonitorRequest,
    UpdateFeatureOperationMetadata,
)
from .feature_selector import (
    FeatureSelector,
    IdMatcher,
)
from .feature_view import (
    FeatureView,
)
from .feature_view_sync import (
    FeatureViewSync,
)
from .featurestore import (
    Featurestore,
)
from .featurestore_monitoring import (
    FeaturestoreMonitoringConfig,
)
from .featurestore_online_service import (
    FeatureValue,
    FeatureValueList,
    ReadFeatureValuesRequest,
    ReadFeatureValuesResponse,
    StreamingReadFeatureValuesRequest,
    StructFieldValue,
    StructValue,
    WriteFeatureValuesPayload,
    WriteFeatureValuesRequest,
    WriteFeatureValuesResponse,
)
from .featurestore_service import (
    BatchCreateFeaturesOperationMetadata,
    BatchCreateFeaturesRequest,
    BatchCreateFeaturesResponse,
    BatchReadFeatureValuesOperationMetadata,
    BatchReadFeatureValuesRequest,
    BatchReadFeatureValuesResponse,
    CreateEntityTypeOperationMetadata,
    CreateEntityTypeRequest,
    CreateFeatureOperationMetadata,
    CreateFeatureRequest,
    CreateFeaturestoreOperationMetadata,
    CreateFeaturestoreRequest,
    DeleteEntityTypeRequest,
    DeleteFeatureRequest,
    DeleteFeaturestoreRequest,
    DeleteFeatureValuesOperationMetadata,
    DeleteFeatureValuesRequest,
    DeleteFeatureValuesResponse,
    DestinationFeatureSetting,
    EntityIdSelector,
    ExportFeatureValuesOperationMetadata,
    ExportFeatureValuesRequest,
    ExportFeatureValuesResponse,
    FeatureValueDestination,
    GetEntityTypeRequest,
    GetFeatureRequest,
    GetFeaturestoreRequest,
    ImportFeatureValuesOperationMetadata,
    ImportFeatureValuesRequest,
    ImportFeatureValuesResponse,
    ListEntityTypesRequest,
    ListEntityTypesResponse,
    ListFeaturesRequest,
    ListFeaturesResponse,
    ListFeaturestoresRequest,
    ListFeaturestoresResponse,
    SearchFeaturesRequest,
    SearchFeaturesResponse,
    UpdateEntityTypeRequest,
    UpdateFeatureRequest,
    UpdateFeaturestoreOperationMetadata,
    UpdateFeaturestoreRequest,
)
from .gen_ai_cache_service import (
    CreateCachedContentRequest,
    DeleteCachedContentRequest,
    GetCachedContentRequest,
    ListCachedContentsRequest,
    ListCachedContentsResponse,
    UpdateCachedContentRequest,
)
from .genai_tuning_service import (
    CancelTuningJobRequest,
    CreateTuningJobRequest,
    GetTuningJobRequest,
    ListTuningJobsRequest,
    ListTuningJobsResponse,
    RebaseTunedModelOperationMetadata,
    RebaseTunedModelRequest,
)
from .hyperparameter_tuning_job import (
    HyperparameterTuningJob,
)
from .index import (
    Index,
    IndexDatapoint,
    IndexStats,
)
from .index_endpoint import (
    DeployedIndex,
    DeployedIndexAuthConfig,
    IndexEndpoint,
    IndexPrivateEndpoints,
)
from .index_endpoint_service import (
    CreateIndexEndpointOperationMetadata,
    CreateIndexEndpointRequest,
    DeleteIndexEndpointRequest,
    DeployIndexOperationMetadata,
    DeployIndexRequest,
    DeployIndexResponse,
    GetIndexEndpointRequest,
    ListIndexEndpointsRequest,
    ListIndexEndpointsResponse,
    MutateDeployedIndexOperationMetadata,
    MutateDeployedIndexRequest,
    MutateDeployedIndexResponse,
    UndeployIndexOperationMetadata,
    UndeployIndexRequest,
    UndeployIndexResponse,
    UpdateIndexEndpointRequest,
)
from .index_service import (
    CreateIndexOperationMetadata,
    CreateIndexRequest,
    DeleteIndexRequest,
    GetIndexRequest,
    ImportIndexOperationMetadata,
    ImportIndexRequest,
    ListIndexesRequest,
    ListIndexesResponse,
    NearestNeighborSearchOperationMetadata,
    RemoveDatapointsRequest,
    RemoveDatapointsResponse,
    UpdateIndexOperationMetadata,
    UpdateIndexRequest,
    UpsertDatapointsRequest,
    UpsertDatapointsResponse,
)
from .io import (
    AvroSource,
    BigQueryDestination,
    BigQuerySource,
    ContainerRegistryDestination,
    CsvDestination,
    CsvSource,
    DirectUploadSource,
    GcsDestination,
    GcsSource,
    GoogleDriveSource,
    JiraSource,
    SharePointSources,
    SlackSource,
    TFRecordDestination,
)
from .job_service import (
    CancelBatchPredictionJobRequest,
    CancelCustomJobRequest,
    CancelDataLabelingJobRequest,
    CancelHyperparameterTuningJobRequest,
    CancelNasJobRequest,
    CreateBatchPredictionJobRequest,
    CreateCustomJobRequest,
    CreateDataLabelingJobRequest,
    CreateHyperparameterTuningJobRequest,
    CreateModelDeploymentMonitoringJobRequest,
    CreateNasJobRequest,
    DeleteBatchPredictionJobRequest,
    DeleteCustomJobRequest,
    DeleteDataLabelingJobRequest,
    DeleteHyperparameterTuningJobRequest,
    DeleteModelDeploymentMonitoringJobRequest,
    DeleteNasJobRequest,
    GetBatchPredictionJobRequest,
    GetCustomJobRequest,
    GetDataLabelingJobRequest,
    GetHyperparameterTuningJobRequest,
    GetModelDeploymentMonitoringJobRequest,
    GetNasJobRequest,
    GetNasTrialDetailRequest,
    ListBatchPredictionJobsRequest,
    ListBatchPredictionJobsResponse,
    ListCustomJobsRequest,
    ListCustomJobsResponse,
    ListDataLabelingJobsRequest,
    ListDataLabelingJobsResponse,
    ListHyperparameterTuningJobsRequest,
    ListHyperparameterTuningJobsResponse,
    ListModelDeploymentMonitoringJobsRequest,
    ListModelDeploymentMonitoringJobsResponse,
    ListNasJobsRequest,
    ListNasJobsResponse,
    ListNasTrialDetailsRequest,
    ListNasTrialDetailsResponse,
    PauseModelDeploymentMonitoringJobRequest,
    ResumeModelDeploymentMonitoringJobRequest,
    SearchModelDeploymentMonitoringStatsAnomaliesRequest,
    SearchModelDeploymentMonitoringStatsAnomaliesResponse,
    UpdateModelDeploymentMonitoringJobOperationMetadata,
    UpdateModelDeploymentMonitoringJobRequest,
)
from .job_state import (
    JobState,
)
from .lineage_subgraph import (
    LineageSubgraph,
)
from .llm_utility_service import (
    ComputeTokensRequest,
    ComputeTokensResponse,
    TokensInfo,
)
from .machine_resources import (
    AutomaticResources,
    AutoscalingMetricSpec,
    BatchDedicatedResources,
    DedicatedResources,
    DiskSpec,
    FlexStart,
    FullFineTunedResources,
    LustreMount,
    MachineSpec,
    NfsMount,
    PersistentDiskSpec,
    ResourcesConsumed,
    ShieldedVmConfig,
)
from .manual_batch_tuning_parameters import (
    ManualBatchTuningParameters,
)
from .match_service import (
    FindNeighborsRequest,
    FindNeighborsResponse,
    ReadIndexDatapointsRequest,
    ReadIndexDatapointsResponse,
)
from .memory_bank import (
    Memory,
)
from .memory_bank_service import (
    CreateMemoryOperationMetadata,
    CreateMemoryRequest,
    DeleteMemoryOperationMetadata,
    DeleteMemoryRequest,
    GenerateMemoriesOperationMetadata,
    GenerateMemoriesRequest,
    GenerateMemoriesResponse,
    GetMemoryRequest,
    ListMemoriesRequest,
    ListMemoriesResponse,
    RetrieveMemoriesRequest,
    RetrieveMemoriesResponse,
    UpdateMemoryOperationMetadata,
    UpdateMemoryRequest,
)
from .metadata_schema import (
    MetadataSchema,
)
from .metadata_service import (
    AddContextArtifactsAndExecutionsRequest,
    AddContextArtifactsAndExecutionsResponse,
    AddContextChildrenRequest,
    AddContextChildrenResponse,
    AddExecutionEventsRequest,
    AddExecutionEventsResponse,
    CreateArtifactRequest,
    CreateContextRequest,
    CreateExecutionRequest,
    CreateMetadataSchemaRequest,
    CreateMetadataStoreOperationMetadata,
    CreateMetadataStoreRequest,
    DeleteArtifactRequest,
    DeleteContextRequest,
    DeleteExecutionRequest,
    DeleteMetadataStoreOperationMetadata,
    DeleteMetadataStoreRequest,
    GetArtifactRequest,
    GetContextRequest,
    GetExecutionRequest,
    GetMetadataSchemaRequest,
    GetMetadataStoreRequest,
    ListArtifactsRequest,
    ListArtifactsResponse,
    ListContextsRequest,
    ListContextsResponse,
    ListExecutionsRequest,
    ListExecutionsResponse,
    ListMetadataSchemasRequest,
    ListMetadataSchemasResponse,
    ListMetadataStoresRequest,
    ListMetadataStoresResponse,
    PurgeArtifactsMetadata,
    PurgeArtifactsRequest,
    PurgeArtifactsResponse,
    PurgeContextsMetadata,
    PurgeContextsRequest,
    PurgeContextsResponse,
    PurgeExecutionsMetadata,
    PurgeExecutionsRequest,
    PurgeExecutionsResponse,
    QueryArtifactLineageSubgraphRequest,
    QueryContextLineageSubgraphRequest,
    QueryExecutionInputsAndOutputsRequest,
    RemoveContextChildrenRequest,
    RemoveContextChildrenResponse,
    UpdateArtifactRequest,
    UpdateContextRequest,
    UpdateExecutionRequest,
)
from .metadata_store import (
    MetadataStore,
)
from .migratable_resource import (
    MigratableResource,
)
from .migration_service import (
    BatchMigrateResourcesOperationMetadata,
    BatchMigrateResourcesRequest,
    BatchMigrateResourcesResponse,
    MigrateResourceRequest,
    MigrateResourceResponse,
    SearchMigratableResourcesRequest,
    SearchMigratableResourcesResponse,
)
from .model import (
    Checkpoint,
    GenieSource,
    LargeModelReference,
    Model,
    ModelContainerSpec,
    ModelGardenSource,
    ModelSourceInfo,
    Port,
    PredictSchemata,
    Probe,
)
from .model_deployment_monitoring_job import (
    ModelDeploymentMonitoringBigQueryTable,
    ModelDeploymentMonitoringJob,
    ModelDeploymentMonitoringObjectiveConfig,
    ModelDeploymentMonitoringScheduleConfig,
    ModelMonitoringStatsAnomalies,
    ModelDeploymentMonitoringObjectiveType,
)
from .model_evaluation import (
    ModelEvaluation,
)
from .model_evaluation_slice import (
    ModelEvaluationSlice,
)
from .model_garden_service import (
    AcceptPublisherModelEulaRequest,
    CheckPublisherModelEulaAcceptanceRequest,
    DeployOperationMetadata,
    DeployPublisherModelOperationMetadata,
    DeployPublisherModelRequest,
    DeployPublisherModelResponse,
    DeployRequest,
    DeployResponse,
    ExportPublisherModelOperationMetadata,
    ExportPublisherModelRequest,
    ExportPublisherModelResponse,
    GetPublisherModelRequest,
    ListPublisherModelsRequest,
    ListPublisherModelsResponse,
    PublisherModelEulaAcceptance,
    PublisherModelView,
)
from .model_monitor import (
    ModelMonitor,
    ModelMonitoringSchema,
)
from .model_monitoring import (
    ModelMonitoringAlertConfig,
    ModelMonitoringConfig,
    ModelMonitoringObjectiveConfig,
    SamplingStrategy,
    ThresholdConfig,
)
from .model_monitoring_alert import (
    ModelMonitoringAlert,
    ModelMonitoringAlertCondition,
    ModelMonitoringAnomaly,
)
from .model_monitoring_job import (
    ModelMonitoringJob,
    ModelMonitoringJobExecutionDetail,
)
from .model_monitoring_service import (
    CreateModelMonitoringJobRequest,
    CreateModelMonitorOperationMetadata,
    CreateModelMonitorRequest,
    DeleteModelMonitoringJobRequest,
    DeleteModelMonitorRequest,
    GetModelMonitoringJobRequest,
    GetModelMonitorRequest,
    ListModelMonitoringJobsRequest,
    ListModelMonitoringJobsResponse,
    ListModelMonitorsRequest,
    ListModelMonitorsResponse,
    SearchModelMonitoringAlertsRequest,
    SearchModelMonitoringAlertsResponse,
    SearchModelMonitoringStatsRequest,
    SearchModelMonitoringStatsResponse,
    UpdateModelMonitorOperationMetadata,
    UpdateModelMonitorRequest,
)
from .model_monitoring_spec import (
    ModelMonitoringInput,
    ModelMonitoringNotificationSpec,
    ModelMonitoringObjectiveSpec,
    ModelMonitoringOutputSpec,
    ModelMonitoringSpec,
)
from .model_monitoring_stats import (
    ModelMonitoringStats,
    ModelMonitoringStatsDataPoint,
    ModelMonitoringTabularStats,
    SearchModelMonitoringStatsFilter,
)
from .model_service import (
    BatchImportEvaluatedAnnotationsRequest,
    BatchImportEvaluatedAnnotationsResponse,
    BatchImportModelEvaluationSlicesRequest,
    BatchImportModelEvaluationSlicesResponse,
    CopyModelOperationMetadata,
    CopyModelRequest,
    CopyModelResponse,
    DeleteModelRequest,
    DeleteModelVersionRequest,
    ExportModelOperationMetadata,
    ExportModelRequest,
    ExportModelResponse,
    GetModelEvaluationRequest,
    GetModelEvaluationSliceRequest,
    GetModelRequest,
    ImportModelEvaluationRequest,
    ListModelEvaluationSlicesRequest,
    ListModelEvaluationSlicesResponse,
    ListModelEvaluationsRequest,
    ListModelEvaluationsResponse,
    ListModelsRequest,
    ListModelsResponse,
    ListModelVersionCheckpointsRequest,
    ListModelVersionCheckpointsResponse,
    ListModelVersionsRequest,
    ListModelVersionsResponse,
    MergeVersionAliasesRequest,
    ModelVersionCheckpoint,
    RecommendSpecRequest,
    RecommendSpecResponse,
    UpdateExplanationDatasetOperationMetadata,
    UpdateExplanationDatasetRequest,
    UpdateExplanationDatasetResponse,
    UpdateModelRequest,
    UploadModelOperationMetadata,
    UploadModelRequest,
    UploadModelResponse,
)
from .nas_job import (
    NasJob,
    NasJobOutput,
    NasJobSpec,
    NasTrial,
    NasTrialDetail,
)
from .network_spec import (
    NetworkSpec,
)
from .notebook_euc_config import (
    NotebookEucConfig,
)
from .notebook_execution_job import (
    NotebookExecutionJob,
)
from .notebook_idle_shutdown_config import (
    NotebookIdleShutdownConfig,
)
from .notebook_runtime import (
    NotebookRuntime,
    NotebookRuntimeTemplate,
    NotebookRuntimeType,
)
from .notebook_runtime_template_ref import (
    NotebookRuntimeTemplateRef,
)
from .notebook_service import (
    AssignNotebookRuntimeOperationMetadata,
    AssignNotebookRuntimeRequest,
    CreateNotebookExecutionJobOperationMetadata,
    CreateNotebookExecutionJobRequest,
    CreateNotebookRuntimeTemplateOperationMetadata,
    CreateNotebookRuntimeTemplateRequest,
    DeleteNotebookExecutionJobRequest,
    DeleteNotebookRuntimeRequest,
    DeleteNotebookRuntimeTemplateRequest,
    GetNotebookExecutionJobRequest,
    GetNotebookRuntimeRequest,
    GetNotebookRuntimeTemplateRequest,
    ListNotebookExecutionJobsRequest,
    ListNotebookExecutionJobsResponse,
    ListNotebookRuntimesRequest,
    ListNotebookRuntimesResponse,
    ListNotebookRuntimeTemplatesRequest,
    ListNotebookRuntimeTemplatesResponse,
    StartNotebookRuntimeOperationMetadata,
    StartNotebookRuntimeRequest,
    StartNotebookRuntimeResponse,
    StopNotebookRuntimeOperationMetadata,
    StopNotebookRuntimeRequest,
    StopNotebookRuntimeResponse,
    UpdateNotebookRuntimeTemplateRequest,
    UpgradeNotebookRuntimeOperationMetadata,
    UpgradeNotebookRuntimeRequest,
    UpgradeNotebookRuntimeResponse,
    NotebookExecutionJobView,
)
from .notebook_software_config import (
    ColabImage,
    NotebookSoftwareConfig,
    PostStartupScriptConfig,
)
from .openapi import (
    Schema,
    Type,
)
from .operation import (
    DeleteOperationMetadata,
    GenericOperationMetadata,
)
from .persistent_resource import (
    PersistentResource,
    RayLogsSpec,
    RayMetricSpec,
    RaySpec,
    ResourcePool,
    ResourceRuntime,
    ResourceRuntimeSpec,
    ServiceAccountSpec,
)
from .persistent_resource_service import (
    CreatePersistentResourceOperationMetadata,
    CreatePersistentResourceRequest,
    DeletePersistentResourceRequest,
    GetPersistentResourceRequest,
    ListPersistentResourcesRequest,
    ListPersistentResourcesResponse,
    RebootPersistentResourceOperationMetadata,
    RebootPersistentResourceRequest,
    UpdatePersistentResourceOperationMetadata,
    UpdatePersistentResourceRequest,
)
from .pipeline_failure_policy import (
    PipelineFailurePolicy,
)
from .pipeline_job import (
    PipelineJob,
    PipelineJobDetail,
    PipelineTaskDetail,
    PipelineTaskExecutorDetail,
    PipelineTaskRerunConfig,
    PipelineTemplateMetadata,
)
from .pipeline_service import (
    BatchCancelPipelineJobsOperationMetadata,
    BatchCancelPipelineJobsRequest,
    BatchCancelPipelineJobsResponse,
    BatchDeletePipelineJobsRequest,
    BatchDeletePipelineJobsResponse,
    CancelPipelineJobRequest,
    CancelTrainingPipelineRequest,
    CreatePipelineJobRequest,
    CreateTrainingPipelineRequest,
    DeletePipelineJobRequest,
    DeleteTrainingPipelineRequest,
    GetPipelineJobRequest,
    GetTrainingPipelineRequest,
    ListPipelineJobsRequest,
    ListPipelineJobsResponse,
    ListTrainingPipelinesRequest,
    ListTrainingPipelinesResponse,
)
from .pipeline_state import (
    PipelineState,
)
from .prediction_service import (
    ChatCompletionsRequest,
    CountTokensRequest,
    CountTokensResponse,
    DirectPredictRequest,
    DirectPredictResponse,
    DirectRawPredictRequest,
    DirectRawPredictResponse,
    EmbedContentRequest,
    EmbedContentResponse,
    ExplainRequest,
    ExplainResponse,
    GenerateContentRequest,
    GenerateContentResponse,
    GenerateVideoResponse,
    PredictLongRunningMetadata,
    PredictLongRunningResponse,
    PredictRequest,
    PredictResponse,
    RawPredictRequest,
    StreamDirectPredictRequest,
    StreamDirectPredictResponse,
    StreamDirectRawPredictRequest,
    StreamDirectRawPredictResponse,
    StreamingPredictRequest,
    StreamingPredictResponse,
    StreamingRawPredictRequest,
    StreamingRawPredictResponse,
    StreamRawPredictRequest,
)
from .publisher_model import (
    PublisherModel,
)
from .reasoning_engine import (
    ReasoningEngine,
    ReasoningEngineContextSpec,
    ReasoningEngineSpec,
)
from .reasoning_engine_execution_service import (
    QueryReasoningEngineRequest,
    QueryReasoningEngineResponse,
    StreamQueryReasoningEngineRequest,
)
from .reasoning_engine_service import (
    CreateReasoningEngineOperationMetadata,
    CreateReasoningEngineRequest,
    DeleteReasoningEngineRequest,
    GetReasoningEngineRequest,
    ListReasoningEnginesRequest,
    ListReasoningEnginesResponse,
    UpdateReasoningEngineOperationMetadata,
    UpdateReasoningEngineRequest,
)
from .reservation_affinity import (
    ReservationAffinity,
)
from .saved_query import (
    SavedQuery,
)
from .schedule import (
    Schedule,
)
from .schedule_service import (
    CreateScheduleRequest,
    DeleteScheduleRequest,
    GetScheduleRequest,
    ListSchedulesRequest,
    ListSchedulesResponse,
    PauseScheduleRequest,
    ResumeScheduleRequest,
    UpdateScheduleRequest,
)
from .service_networking import (
    DnsPeeringConfig,
    PrivateServiceConnectConfig,
    PscAutomatedEndpoints,
    PSCAutomationConfig,
    PscInterfaceConfig,
    PSCAutomationState,
)
from .session import (
    EventActions,
    EventMetadata,
    Session,
    SessionEvent,
)
from .session_service import (
    AppendEventRequest,
    AppendEventResponse,
    CreateSessionOperationMetadata,
    CreateSessionRequest,
    DeleteSessionRequest,
    GetSessionRequest,
    ListEventsRequest,
    ListEventsResponse,
    ListSessionsRequest,
    ListSessionsResponse,
    UpdateSessionRequest,
)
from .specialist_pool import (
    SpecialistPool,
)
from .specialist_pool_service import (
    CreateSpecialistPoolOperationMetadata,
    CreateSpecialistPoolRequest,
    DeleteSpecialistPoolRequest,
    GetSpecialistPoolRequest,
    ListSpecialistPoolsRequest,
    ListSpecialistPoolsResponse,
    UpdateSpecialistPoolOperationMetadata,
    UpdateSpecialistPoolRequest,
)
from .study import (
    Measurement,
    Study,
    StudySpec,
    StudyTimeConstraint,
    Trial,
    TrialContext,
)
from .tensorboard import (
    Tensorboard,
)
from .tensorboard_data import (
    Scalar,
    TensorboardBlob,
    TensorboardBlobSequence,
    TensorboardTensor,
    TimeSeriesData,
    TimeSeriesDataPoint,
)
from .tensorboard_experiment import (
    TensorboardExperiment,
)
from .tensorboard_run import (
    TensorboardRun,
)
from .tensorboard_service import (
    BatchCreateTensorboardRunsRequest,
    BatchCreateTensorboardRunsResponse,
    BatchCreateTensorboardTimeSeriesRequest,
    BatchCreateTensorboardTimeSeriesResponse,
    BatchReadTensorboardTimeSeriesDataRequest,
    BatchReadTensorboardTimeSeriesDataResponse,
    CreateTensorboardExperimentRequest,
    CreateTensorboardOperationMetadata,
    CreateTensorboardRequest,
    CreateTensorboardRunRequest,
    CreateTensorboardTimeSeriesRequest,
    DeleteTensorboardExperimentRequest,
    DeleteTensorboardRequest,
    DeleteTensorboardRunRequest,
    DeleteTensorboardTimeSeriesRequest,
    ExportTensorboardTimeSeriesDataRequest,
    ExportTensorboardTimeSeriesDataResponse,
    GetTensorboardExperimentRequest,
    GetTensorboardRequest,
    GetTensorboardRunRequest,
    GetTensorboardTimeSeriesRequest,
    ListTensorboardExperimentsRequest,
    ListTensorboardExperimentsResponse,
    ListTensorboardRunsRequest,
    ListTensorboardRunsResponse,
    ListTensorboardsRequest,
    ListTensorboardsResponse,
    ListTensorboardTimeSeriesRequest,
    ListTensorboardTimeSeriesResponse,
    ReadTensorboardBlobDataRequest,
    ReadTensorboardBlobDataResponse,
    ReadTensorboardSizeRequest,
    ReadTensorboardSizeResponse,
    ReadTensorboardTimeSeriesDataRequest,
    ReadTensorboardTimeSeriesDataResponse,
    ReadTensorboardUsageRequest,
    ReadTensorboardUsageResponse,
    UpdateTensorboardExperimentRequest,
    UpdateTensorboardOperationMetadata,
    UpdateTensorboardRequest,
    UpdateTensorboardRunRequest,
    UpdateTensorboardTimeSeriesRequest,
    WriteTensorboardExperimentDataRequest,
    WriteTensorboardExperimentDataResponse,
    WriteTensorboardRunDataRequest,
    WriteTensorboardRunDataResponse,
)
from .tensorboard_time_series import (
    TensorboardTimeSeries,
)
from .tool import (
    CodeExecutionResult,
    DynamicRetrievalConfig,
    EnterpriseWebSearch,
    ExecutableCode,
    FunctionCall,
    FunctionCallingConfig,
    FunctionDeclaration,
    FunctionResponse,
    FunctionResponseBlob,
    FunctionResponseFileData,
    FunctionResponsePart,
    GoogleMaps,
    GoogleSearchRetrieval,
    RagRetrievalConfig,
    Retrieval,
    RetrievalConfig,
    Tool,
    ToolConfig,
    ToolUseExample,
    UrlContext,
    VertexAISearch,
    VertexRagStore,
)
from .training_pipeline import (
    FilterSplit,
    FractionSplit,
    InputDataConfig,
    PredefinedSplit,
    StratifiedSplit,
    TimestampSplit,
    TrainingPipeline,
)
from .tuning_job import (
    DatasetDistribution,
    DatasetStats,
    DistillationDataStats,
    DistillationHyperParameters,
    DistillationSpec,
    EvaluateDatasetRun,
    EvaluationConfig,
    PartnerModelTuningSpec,
    PreTunedModel,
    SupervisedHyperParameters,
    SupervisedTuningDatasetDistribution,
    SupervisedTuningDataStats,
    SupervisedTuningSpec,
    TunedModel,
    TunedModelCheckpoint,
    TunedModelRef,
    TuningDataStats,
    TuningJob,
    VeoHyperParameters,
    VeoTuningSpec,
)
from .types import (
    BoolArray,
    DoubleArray,
    Int64Array,
    StringArray,
    Tensor,
)
from .ui_pipeline_spec import (
    ArtifactTypeSchema,
    RuntimeArtifact,
)
from .unmanaged_container_model import (
    UnmanagedContainerModel,
)
from .usage_metadata import (
    UsageMetadata,
)
from .user_action_reference import (
    UserActionReference,
)
from .value import (
    Value,
)
from .vertex_rag_data import (
    CorpusStatus,
    FileStatus,
    ImportRagFilesConfig,
    RagChunk,
    RagCorpus,
    RagEmbeddingModelConfig,
    RagEngineConfig,
    RagFile,
    RagFileChunkingConfig,
    RagFileMetadataConfig,
    RagFileParsingConfig,
    RagFileTransformationConfig,
    RagManagedDbConfig,
    RagVectorDbConfig,
    UploadRagFileConfig,
    VertexAiSearchConfig,
)
from .vertex_rag_data_service import (
    CreateRagCorpusOperationMetadata,
    CreateRagCorpusRequest,
    DeleteRagCorpusRequest,
    DeleteRagFileRequest,
    GetRagCorpusRequest,
    GetRagEngineConfigRequest,
    GetRagFileRequest,
    ImportRagFilesOperationMetadata,
    ImportRagFilesRequest,
    ImportRagFilesResponse,
    ListRagCorporaRequest,
    ListRagCorporaResponse,
    ListRagFilesRequest,
    ListRagFilesResponse,
    UpdateRagCorpusOperationMetadata,
    UpdateRagCorpusRequest,
    UpdateRagEngineConfigOperationMetadata,
    UpdateRagEngineConfigRequest,
    UploadRagFileRequest,
    UploadRagFileResponse,
)
from .vertex_rag_service import (
    AugmentPromptRequest,
    AugmentPromptResponse,
    Claim,
    CorroborateContentRequest,
    CorroborateContentResponse,
    Fact,
    RagContexts,
    RagQuery,
    RetrieveContextsRequest,
    RetrieveContextsResponse,
)
from .vizier_service import (
    AddTrialMeasurementRequest,
    CheckTrialEarlyStoppingStateMetatdata,
    CheckTrialEarlyStoppingStateRequest,
    CheckTrialEarlyStoppingStateResponse,
    CompleteTrialRequest,
    CreateStudyRequest,
    CreateTrialRequest,
    DeleteStudyRequest,
    DeleteTrialRequest,
    GetStudyRequest,
    GetTrialRequest,
    ListOptimalTrialsRequest,
    ListOptimalTrialsResponse,
    ListStudiesRequest,
    ListStudiesResponse,
    ListTrialsRequest,
    ListTrialsResponse,
    LookupStudyRequest,
    StopTrialRequest,
    SuggestTrialsMetadata,
    SuggestTrialsRequest,
    SuggestTrialsResponse,
)

__all__ = (
    "AcceleratorType",
    "Annotation",
    "AnnotationSpec",
    "ApiAuth",
    "Artifact",
    "BatchPredictionJob",
    "CachedContent",
    "CompletionStats",
    "Blob",
    "Candidate",
    "Citation",
    "CitationMetadata",
    "Content",
    "FileData",
    "GenerationConfig",
    "GroundingChunk",
    "GroundingMetadata",
    "GroundingSupport",
    "ImageConfig",
    "LogprobsResult",
    "ModalityTokenCount",
    "ModelArmorConfig",
    "MultiSpeakerVoiceConfig",
    "Part",
    "PrebuiltVoiceConfig",
    "ReplicatedVoiceConfig",
    "RetrievalMetadata",
    "SafetyRating",
    "SafetySetting",
    "SearchEntryPoint",
    "Segment",
    "SpeakerVoiceConfig",
    "SpeechConfig",
    "UrlContextMetadata",
    "UrlMetadata",
    "VideoMetadata",
    "VoiceConfig",
    "HarmCategory",
    "Modality",
    "Context",
    "ContainerSpec",
    "CustomJob",
    "CustomJobSpec",
    "PythonPackageSpec",
    "Scheduling",
    "WorkerPoolSpec",
    "DataItem",
    "ActiveLearningConfig",
    "DataLabelingJob",
    "SampleConfig",
    "TrainingConfig",
    "Dataset",
    "ExportDataConfig",
    "ExportFractionSplit",
    "ImportDataConfig",
    "AssembleDataOperationMetadata",
    "AssembleDataRequest",
    "AssembleDataResponse",
    "AssessDataOperationMetadata",
    "AssessDataRequest",
    "AssessDataResponse",
    "CreateDatasetOperationMetadata",
    "CreateDatasetRequest",
    "CreateDatasetVersionOperationMetadata",
    "CreateDatasetVersionRequest",
    "DataItemView",
    "DeleteDatasetRequest",
    "DeleteDatasetVersionRequest",
    "DeleteSavedQueryRequest",
    "ExportDataOperationMetadata",
    "ExportDataRequest",
    "ExportDataResponse",
    "GeminiExample",
    "GeminiRequestReadConfig",
    "GeminiTemplateConfig",
    "GetAnnotationSpecRequest",
    "GetDatasetRequest",
    "GetDatasetVersionRequest",
    "ImportDataOperationMetadata",
    "ImportDataRequest",
    "ImportDataResponse",
    "ListAnnotationsRequest",
    "ListAnnotationsResponse",
    "ListDataItemsRequest",
    "ListDataItemsResponse",
    "ListDatasetsRequest",
    "ListDatasetsResponse",
    "ListDatasetVersionsRequest",
    "ListDatasetVersionsResponse",
    "ListSavedQueriesRequest",
    "ListSavedQueriesResponse",
    "RestoreDatasetVersionOperationMetadata",
    "RestoreDatasetVersionRequest",
    "SearchDataItemsRequest",
    "SearchDataItemsResponse",
    "UpdateDatasetRequest",
    "UpdateDatasetVersionRequest",
    "DatasetVersion",
    "DeployedIndexRef",
    "DeployedModelRef",
    "DeploymentResourcePool",
    "CreateDeploymentResourcePoolOperationMetadata",
    "CreateDeploymentResourcePoolRequest",
    "DeleteDeploymentResourcePoolRequest",
    "GetDeploymentResourcePoolRequest",
    "ListDeploymentResourcePoolsRequest",
    "ListDeploymentResourcePoolsResponse",
    "QueryDeployedModelsRequest",
    "QueryDeployedModelsResponse",
    "UpdateDeploymentResourcePoolOperationMetadata",
    "UpdateDeploymentResourcePoolRequest",
    "DeploymentStage",
    "EncryptionSpec",
    "ClientConnectionConfig",
    "DeployedModel",
    "Endpoint",
    "FasterDeploymentConfig",
    "GenAiAdvancedFeaturesConfig",
    "PredictRequestResponseLoggingConfig",
    "PrivateEndpoints",
    "PublisherModelConfig",
    "RolloutOptions",
    "SpeculativeDecodingSpec",
    "CreateEndpointOperationMetadata",
    "CreateEndpointRequest",
    "DeleteEndpointRequest",
    "DeployModelOperationMetadata",
    "DeployModelRequest",
    "DeployModelResponse",
    "FetchPublisherModelConfigRequest",
    "GetEndpointRequest",
    "ListEndpointsRequest",
    "ListEndpointsResponse",
    "MutateDeployedModelOperationMetadata",
    "MutateDeployedModelRequest",
    "MutateDeployedModelResponse",
    "SetPublisherModelConfigOperationMetadata",
    "SetPublisherModelConfigRequest",
    "UndeployModelOperationMetadata",
    "UndeployModelRequest",
    "UndeployModelResponse",
    "UpdateEndpointLongRunningRequest",
    "UpdateEndpointOperationMetadata",
    "UpdateEndpointRequest",
    "EntityType",
    "EnvVar",
    "SecretEnvVar",
    "SecretRef",
    "ErrorAnalysisAnnotation",
    "EvaluatedAnnotation",
    "EvaluatedAnnotationExplanation",
    "AggregationOutput",
    "AggregationResult",
    "AutoraterConfig",
    "BleuInput",
    "BleuInstance",
    "BleuMetricValue",
    "BleuResults",
    "BleuSpec",
    "CoherenceInput",
    "CoherenceInstance",
    "CoherenceResult",
    "CoherenceSpec",
    "CometInput",
    "CometInstance",
    "CometResult",
    "CometSpec",
    "ContentMap",
    "CustomOutput",
    "CustomOutputFormatConfig",
    "EvaluateDatasetOperationMetadata",
    "EvaluateDatasetRequest",
    "EvaluateDatasetResponse",
    "EvaluateInstancesRequest",
    "EvaluateInstancesResponse",
    "EvaluationDataset",
    "ExactMatchInput",
    "ExactMatchInstance",
    "ExactMatchMetricValue",
    "ExactMatchResults",
    "ExactMatchSpec",
    "FluencyInput",
    "FluencyInstance",
    "FluencyResult",
    "FluencySpec",
    "FulfillmentInput",
    "FulfillmentInstance",
    "FulfillmentResult",
    "FulfillmentSpec",
    "GroundednessInput",
    "GroundednessInstance",
    "GroundednessResult",
    "GroundednessSpec",
    "Metric",
    "MetricxInput",
    "MetricxInstance",
    "MetricxResult",
    "MetricxSpec",
    "OutputConfig",
    "OutputInfo",
    "PairwiseMetricInput",
    "PairwiseMetricInstance",
    "PairwiseMetricResult",
    "PairwiseMetricSpec",
    "PairwiseQuestionAnsweringQualityInput",
    "PairwiseQuestionAnsweringQualityInstance",
    "PairwiseQuestionAnsweringQualityResult",
    "PairwiseQuestionAnsweringQualitySpec",
    "PairwiseSummarizationQualityInput",
    "PairwiseSummarizationQualityInstance",
    "PairwiseSummarizationQualityResult",
    "PairwiseSummarizationQualitySpec",
    "PointwiseMetricInput",
    "PointwiseMetricInstance",
    "PointwiseMetricResult",
    "PointwiseMetricSpec",
    "QuestionAnsweringCorrectnessInput",
    "QuestionAnsweringCorrectnessInstance",
    "QuestionAnsweringCorrectnessResult",
    "QuestionAnsweringCorrectnessSpec",
    "QuestionAnsweringHelpfulnessInput",
    "QuestionAnsweringHelpfulnessInstance",
    "QuestionAnsweringHelpfulnessResult",
    "QuestionAnsweringHelpfulnessSpec",
    "QuestionAnsweringQualityInput",
    "QuestionAnsweringQualityInstance",
    "QuestionAnsweringQualityResult",
    "QuestionAnsweringQualitySpec",
    "QuestionAnsweringRelevanceInput",
    "QuestionAnsweringRelevanceInstance",
    "QuestionAnsweringRelevanceResult",
    "QuestionAnsweringRelevanceSpec",
    "RawOutput",
    "RougeInput",
    "RougeInstance",
    "RougeMetricValue",
    "RougeResults",
    "RougeSpec",
    "RubricBasedInstructionFollowingInput",
    "RubricBasedInstructionFollowingInstance",
    "RubricBasedInstructionFollowingResult",
    "RubricBasedInstructionFollowingSpec",
    "RubricCritiqueResult",
    "SafetyInput",
    "SafetyInstance",
    "SafetyResult",
    "SafetySpec",
    "SummarizationHelpfulnessInput",
    "SummarizationHelpfulnessInstance",
    "SummarizationHelpfulnessResult",
    "SummarizationHelpfulnessSpec",
    "SummarizationQualityInput",
    "SummarizationQualityInstance",
    "SummarizationQualityResult",
    "SummarizationQualitySpec",
    "SummarizationVerbosityInput",
    "SummarizationVerbosityInstance",
    "SummarizationVerbosityResult",
    "SummarizationVerbositySpec",
    "ToolCall",
    "ToolCallValidInput",
    "ToolCallValidInstance",
    "ToolCallValidMetricValue",
    "ToolCallValidResults",
    "ToolCallValidSpec",
    "ToolNameMatchInput",
    "ToolNameMatchInstance",
    "ToolNameMatchMetricValue",
    "ToolNameMatchResults",
    "ToolNameMatchSpec",
    "ToolParameterKeyMatchInput",
    "ToolParameterKeyMatchInstance",
    "ToolParameterKeyMatchMetricValue",
    "ToolParameterKeyMatchResults",
    "ToolParameterKeyMatchSpec",
    "ToolParameterKVMatchInput",
    "ToolParameterKVMatchInstance",
    "ToolParameterKVMatchMetricValue",
    "ToolParameterKVMatchResults",
    "ToolParameterKVMatchSpec",
    "Trajectory",
    "TrajectoryAnyOrderMatchInput",
    "TrajectoryAnyOrderMatchInstance",
    "TrajectoryAnyOrderMatchMetricValue",
    "TrajectoryAnyOrderMatchResults",
    "TrajectoryAnyOrderMatchSpec",
    "TrajectoryExactMatchInput",
    "TrajectoryExactMatchInstance",
    "TrajectoryExactMatchMetricValue",
    "TrajectoryExactMatchResults",
    "TrajectoryExactMatchSpec",
    "TrajectoryInOrderMatchInput",
    "TrajectoryInOrderMatchInstance",
    "TrajectoryInOrderMatchMetricValue",
    "TrajectoryInOrderMatchResults",
    "TrajectoryInOrderMatchSpec",
    "TrajectoryPrecisionInput",
    "TrajectoryPrecisionInstance",
    "TrajectoryPrecisionMetricValue",
    "TrajectoryPrecisionResults",
    "TrajectoryPrecisionSpec",
    "TrajectoryRecallInput",
    "TrajectoryRecallInstance",
    "TrajectoryRecallMetricValue",
    "TrajectoryRecallResults",
    "TrajectoryRecallSpec",
    "TrajectorySingleToolUseInput",
    "TrajectorySingleToolUseInstance",
    "TrajectorySingleToolUseMetricValue",
    "TrajectorySingleToolUseResults",
    "TrajectorySingleToolUseSpec",
    "PairwiseChoice",
    "Event",
    "ContentsExample",
    "StoredContentsExample",
    "ExamplesArrayFilter",
    "ExampleStore",
    "ExampleStoreConfig",
    "StoredContentsExampleFilter",
    "StoredContentsExampleParameters",
    "CreateExampleStoreOperationMetadata",
    "CreateExampleStoreRequest",
    "DeleteExampleStoreOperationMetadata",
    "DeleteExampleStoreRequest",
    "Example",
    "FetchExamplesRequest",
    "FetchExamplesResponse",
    "GetExampleStoreRequest",
    "ListExampleStoresRequest",
    "ListExampleStoresResponse",
    "RemoveExamplesRequest",
    "RemoveExamplesResponse",
    "SearchExamplesRequest",
    "SearchExamplesResponse",
    "UpdateExampleStoreOperationMetadata",
    "UpdateExampleStoreRequest",
    "UpsertExamplesRequest",
    "UpsertExamplesResponse",
    "Execution",
    "Attribution",
    "BlurBaselineConfig",
    "Examples",
    "ExamplesOverride",
    "ExamplesRestrictionsNamespace",
    "Explanation",
    "ExplanationMetadataOverride",
    "ExplanationParameters",
    "ExplanationSpec",
    "ExplanationSpecOverride",
    "FeatureNoiseSigma",
    "IntegratedGradientsAttribution",
    "ModelExplanation",
    "Neighbor",
    "Presets",
    "SampledShapleyAttribution",
    "SmoothGradConfig",
    "XraiAttribution",
    "ExplanationMetadata",
    "AuthConfig",
    "Extension",
    "ExtensionManifest",
    "ExtensionOperation",
    "ExtensionPrivateServiceConnectConfig",
    "RuntimeConfig",
    "AuthType",
    "HttpElementLocation",
    "ExecuteExtensionRequest",
    "ExecuteExtensionResponse",
    "QueryExtensionRequest",
    "QueryExtensionResponse",
    "DeleteExtensionRequest",
    "GetExtensionRequest",
    "ImportExtensionOperationMetadata",
    "ImportExtensionRequest",
    "ListExtensionsRequest",
    "ListExtensionsResponse",
    "UpdateExtensionRequest",
    "Feature",
    "FeatureGroup",
    "FeatureMonitor",
    "FeatureSelectionConfig",
    "FeatureStatsAndAnomaly",
    "FeatureStatsAndAnomalySpec",
    "ScheduleConfig",
    "FeatureMonitorJob",
    "FeatureStatsAnomaly",
    "FeatureOnlineStore",
    "CreateFeatureOnlineStoreOperationMetadata",
    "CreateFeatureOnlineStoreRequest",
    "CreateFeatureViewOperationMetadata",
    "CreateFeatureViewRequest",
    "DeleteFeatureOnlineStoreRequest",
    "DeleteFeatureViewRequest",
    "GetFeatureOnlineStoreRequest",
    "GetFeatureViewRequest",
    "GetFeatureViewSyncRequest",
    "ListFeatureOnlineStoresRequest",
    "ListFeatureOnlineStoresResponse",
    "ListFeatureViewsRequest",
    "ListFeatureViewsResponse",
    "ListFeatureViewSyncsRequest",
    "ListFeatureViewSyncsResponse",
    "SyncFeatureViewRequest",
    "SyncFeatureViewResponse",
    "UpdateFeatureOnlineStoreOperationMetadata",
    "UpdateFeatureOnlineStoreRequest",
    "UpdateFeatureViewOperationMetadata",
    "UpdateFeatureViewRequest",
    "FeatureViewDataKey",
    "FeatureViewDirectWriteRequest",
    "FeatureViewDirectWriteResponse",
    "FetchFeatureValuesRequest",
    "FetchFeatureValuesResponse",
    "GenerateFetchAccessTokenRequest",
    "GenerateFetchAccessTokenResponse",
    "NearestNeighborQuery",
    "NearestNeighbors",
    "SearchNearestEntitiesRequest",
    "SearchNearestEntitiesResponse",
    "StreamingFetchFeatureValuesRequest",
    "StreamingFetchFeatureValuesResponse",
    "FeatureViewDataFormat",
    "CreateFeatureGroupOperationMetadata",
    "CreateFeatureGroupRequest",
    "CreateFeatureMonitorJobRequest",
    "CreateFeatureMonitorOperationMetadata",
    "CreateFeatureMonitorRequest",
    "CreateRegistryFeatureOperationMetadata",
    "DeleteFeatureGroupRequest",
    "DeleteFeatureMonitorRequest",
    "GetFeatureGroupRequest",
    "GetFeatureMonitorJobRequest",
    "GetFeatureMonitorRequest",
    "ListFeatureGroupsRequest",
    "ListFeatureGroupsResponse",
    "ListFeatureMonitorJobsRequest",
    "ListFeatureMonitorJobsResponse",
    "ListFeatureMonitorsRequest",
    "ListFeatureMonitorsResponse",
    "UpdateFeatureGroupOperationMetadata",
    "UpdateFeatureGroupRequest",
    "UpdateFeatureMonitorOperationMetadata",
    "UpdateFeatureMonitorRequest",
    "UpdateFeatureOperationMetadata",
    "FeatureSelector",
    "IdMatcher",
    "FeatureView",
    "FeatureViewSync",
    "Featurestore",
    "FeaturestoreMonitoringConfig",
    "FeatureValue",
    "FeatureValueList",
    "ReadFeatureValuesRequest",
    "ReadFeatureValuesResponse",
    "StreamingReadFeatureValuesRequest",
    "StructFieldValue",
    "StructValue",
    "WriteFeatureValuesPayload",
    "WriteFeatureValuesRequest",
    "WriteFeatureValuesResponse",
    "BatchCreateFeaturesOperationMetadata",
    "BatchCreateFeaturesRequest",
    "BatchCreateFeaturesResponse",
    "BatchReadFeatureValuesOperationMetadata",
    "BatchReadFeatureValuesRequest",
    "BatchReadFeatureValuesResponse",
    "CreateEntityTypeOperationMetadata",
    "CreateEntityTypeRequest",
    "CreateFeatureOperationMetadata",
    "CreateFeatureRequest",
    "CreateFeaturestoreOperationMetadata",
    "CreateFeaturestoreRequest",
    "DeleteEntityTypeRequest",
    "DeleteFeatureRequest",
    "DeleteFeaturestoreRequest",
    "DeleteFeatureValuesOperationMetadata",
    "DeleteFeatureValuesRequest",
    "DeleteFeatureValuesResponse",
    "DestinationFeatureSetting",
    "EntityIdSelector",
    "ExportFeatureValuesOperationMetadata",
    "ExportFeatureValuesRequest",
    "ExportFeatureValuesResponse",
    "FeatureValueDestination",
    "GetEntityTypeRequest",
    "GetFeatureRequest",
    "GetFeaturestoreRequest",
    "ImportFeatureValuesOperationMetadata",
    "ImportFeatureValuesRequest",
    "ImportFeatureValuesResponse",
    "ListEntityTypesRequest",
    "ListEntityTypesResponse",
    "ListFeaturesRequest",
    "ListFeaturesResponse",
    "ListFeaturestoresRequest",
    "ListFeaturestoresResponse",
    "SearchFeaturesRequest",
    "SearchFeaturesResponse",
    "UpdateEntityTypeRequest",
    "UpdateFeatureRequest",
    "UpdateFeaturestoreOperationMetadata",
    "UpdateFeaturestoreRequest",
    "CreateCachedContentRequest",
    "DeleteCachedContentRequest",
    "GetCachedContentRequest",
    "ListCachedContentsRequest",
    "ListCachedContentsResponse",
    "UpdateCachedContentRequest",
    "CancelTuningJobRequest",
    "CreateTuningJobRequest",
    "GetTuningJobRequest",
    "ListTuningJobsRequest",
    "ListTuningJobsResponse",
    "RebaseTunedModelOperationMetadata",
    "RebaseTunedModelRequest",
    "HyperparameterTuningJob",
    "Index",
    "IndexDatapoint",
    "IndexStats",
    "DeployedIndex",
    "DeployedIndexAuthConfig",
    "IndexEndpoint",
    "IndexPrivateEndpoints",
    "CreateIndexEndpointOperationMetadata",
    "CreateIndexEndpointRequest",
    "DeleteIndexEndpointRequest",
    "DeployIndexOperationMetadata",
    "DeployIndexRequest",
    "DeployIndexResponse",
    "GetIndexEndpointRequest",
    "ListIndexEndpointsRequest",
    "ListIndexEndpointsResponse",
    "MutateDeployedIndexOperationMetadata",
    "MutateDeployedIndexRequest",
    "MutateDeployedIndexResponse",
    "UndeployIndexOperationMetadata",
    "UndeployIndexRequest",
    "UndeployIndexResponse",
    "UpdateIndexEndpointRequest",
    "CreateIndexOperationMetadata",
    "CreateIndexRequest",
    "DeleteIndexRequest",
    "GetIndexRequest",
    "ImportIndexOperationMetadata",
    "ImportIndexRequest",
    "ListIndexesRequest",
    "ListIndexesResponse",
    "NearestNeighborSearchOperationMetadata",
    "RemoveDatapointsRequest",
    "RemoveDatapointsResponse",
    "UpdateIndexOperationMetadata",
    "UpdateIndexRequest",
    "UpsertDatapointsRequest",
    "UpsertDatapointsResponse",
    "AvroSource",
    "BigQueryDestination",
    "BigQuerySource",
    "ContainerRegistryDestination",
    "CsvDestination",
    "CsvSource",
    "DirectUploadSource",
    "GcsDestination",
    "GcsSource",
    "GoogleDriveSource",
    "JiraSource",
    "SharePointSources",
    "SlackSource",
    "TFRecordDestination",
    "CancelBatchPredictionJobRequest",
    "CancelCustomJobRequest",
    "CancelDataLabelingJobRequest",
    "CancelHyperparameterTuningJobRequest",
    "CancelNasJobRequest",
    "CreateBatchPredictionJobRequest",
    "CreateCustomJobRequest",
    "CreateDataLabelingJobRequest",
    "CreateHyperparameterTuningJobRequest",
    "CreateModelDeploymentMonitoringJobRequest",
    "CreateNasJobRequest",
    "DeleteBatchPredictionJobRequest",
    "DeleteCustomJobRequest",
    "DeleteDataLabelingJobRequest",
    "DeleteHyperparameterTuningJobRequest",
    "DeleteModelDeploymentMonitoringJobRequest",
    "DeleteNasJobRequest",
    "GetBatchPredictionJobRequest",
    "GetCustomJobRequest",
    "GetDataLabelingJobRequest",
    "GetHyperparameterTuningJobRequest",
    "GetModelDeploymentMonitoringJobRequest",
    "GetNasJobRequest",
    "GetNasTrialDetailRequest",
    "ListBatchPredictionJobsRequest",
    "ListBatchPredictionJobsResponse",
    "ListCustomJobsRequest",
    "ListCustomJobsResponse",
    "ListDataLabelingJobsRequest",
    "ListDataLabelingJobsResponse",
    "ListHyperparameterTuningJobsRequest",
    "ListHyperparameterTuningJobsResponse",
    "ListModelDeploymentMonitoringJobsRequest",
    "ListModelDeploymentMonitoringJobsResponse",
    "ListNasJobsRequest",
    "ListNasJobsResponse",
    "ListNasTrialDetailsRequest",
    "ListNasTrialDetailsResponse",
    "PauseModelDeploymentMonitoringJobRequest",
    "ResumeModelDeploymentMonitoringJobRequest",
    "SearchModelDeploymentMonitoringStatsAnomaliesRequest",
    "SearchModelDeploymentMonitoringStatsAnomaliesResponse",
    "UpdateModelDeploymentMonitoringJobOperationMetadata",
    "UpdateModelDeploymentMonitoringJobRequest",
    "JobState",
    "LineageSubgraph",
    "ComputeTokensRequest",
    "ComputeTokensResponse",
    "TokensInfo",
    "AutomaticResources",
    "AutoscalingMetricSpec",
    "BatchDedicatedResources",
    "DedicatedResources",
    "DiskSpec",
    "FlexStart",
    "FullFineTunedResources",
    "LustreMount",
    "MachineSpec",
    "NfsMount",
    "PersistentDiskSpec",
    "ResourcesConsumed",
    "ShieldedVmConfig",
    "ManualBatchTuningParameters",
    "FindNeighborsRequest",
    "FindNeighborsResponse",
    "ReadIndexDatapointsRequest",
    "ReadIndexDatapointsResponse",
    "Memory",
    "CreateMemoryOperationMetadata",
    "CreateMemoryRequest",
    "DeleteMemoryOperationMetadata",
    "DeleteMemoryRequest",
    "GenerateMemoriesOperationMetadata",
    "GenerateMemoriesRequest",
    "GenerateMemoriesResponse",
    "GetMemoryRequest",
    "ListMemoriesRequest",
    "ListMemoriesResponse",
    "RetrieveMemoriesRequest",
    "RetrieveMemoriesResponse",
    "UpdateMemoryOperationMetadata",
    "UpdateMemoryRequest",
    "MetadataSchema",
    "AddContextArtifactsAndExecutionsRequest",
    "AddContextArtifactsAndExecutionsResponse",
    "AddContextChildrenRequest",
    "AddContextChildrenResponse",
    "AddExecutionEventsRequest",
    "AddExecutionEventsResponse",
    "CreateArtifactRequest",
    "CreateContextRequest",
    "CreateExecutionRequest",
    "CreateMetadataSchemaRequest",
    "CreateMetadataStoreOperationMetadata",
    "CreateMetadataStoreRequest",
    "DeleteArtifactRequest",
    "DeleteContextRequest",
    "DeleteExecutionRequest",
    "DeleteMetadataStoreOperationMetadata",
    "DeleteMetadataStoreRequest",
    "GetArtifactRequest",
    "GetContextRequest",
    "GetExecutionRequest",
    "GetMetadataSchemaRequest",
    "GetMetadataStoreRequest",
    "ListArtifactsRequest",
    "ListArtifactsResponse",
    "ListContextsRequest",
    "ListContextsResponse",
    "ListExecutionsRequest",
    "ListExecutionsResponse",
    "ListMetadataSchemasRequest",
    "ListMetadataSchemasResponse",
    "ListMetadataStoresRequest",
    "ListMetadataStoresResponse",
    "PurgeArtifactsMetadata",
    "PurgeArtifactsRequest",
    "PurgeArtifactsResponse",
    "PurgeContextsMetadata",
    "PurgeContextsRequest",
    "PurgeContextsResponse",
    "PurgeExecutionsMetadata",
    "PurgeExecutionsRequest",
    "PurgeExecutionsResponse",
    "QueryArtifactLineageSubgraphRequest",
    "QueryContextLineageSubgraphRequest",
    "QueryExecutionInputsAndOutputsRequest",
    "RemoveContextChildrenRequest",
    "RemoveContextChildrenResponse",
    "UpdateArtifactRequest",
    "UpdateContextRequest",
    "UpdateExecutionRequest",
    "MetadataStore",
    "MigratableResource",
    "BatchMigrateResourcesOperationMetadata",
    "BatchMigrateResourcesRequest",
    "BatchMigrateResourcesResponse",
    "MigrateResourceRequest",
    "MigrateResourceResponse",
    "SearchMigratableResourcesRequest",
    "SearchMigratableResourcesResponse",
    "Checkpoint",
    "GenieSource",
    "LargeModelReference",
    "Model",
    "ModelContainerSpec",
    "ModelGardenSource",
    "ModelSourceInfo",
    "Port",
    "PredictSchemata",
    "Probe",
    "ModelDeploymentMonitoringBigQueryTable",
    "ModelDeploymentMonitoringJob",
    "ModelDeploymentMonitoringObjectiveConfig",
    "ModelDeploymentMonitoringScheduleConfig",
    "ModelMonitoringStatsAnomalies",
    "ModelDeploymentMonitoringObjectiveType",
    "ModelEvaluation",
    "ModelEvaluationSlice",
    "AcceptPublisherModelEulaRequest",
    "CheckPublisherModelEulaAcceptanceRequest",
    "DeployOperationMetadata",
    "DeployPublisherModelOperationMetadata",
    "DeployPublisherModelRequest",
    "DeployPublisherModelResponse",
    "DeployRequest",
    "DeployResponse",
    "ExportPublisherModelOperationMetadata",
    "ExportPublisherModelRequest",
    "ExportPublisherModelResponse",
    "GetPublisherModelRequest",
    "ListPublisherModelsRequest",
    "ListPublisherModelsResponse",
    "PublisherModelEulaAcceptance",
    "PublisherModelView",
    "ModelMonitor",
    "ModelMonitoringSchema",
    "ModelMonitoringAlertConfig",
    "ModelMonitoringConfig",
    "ModelMonitoringObjectiveConfig",
    "SamplingStrategy",
    "ThresholdConfig",
    "ModelMonitoringAlert",
    "ModelMonitoringAlertCondition",
    "ModelMonitoringAnomaly",
    "ModelMonitoringJob",
    "ModelMonitoringJobExecutionDetail",
    "CreateModelMonitoringJobRequest",
    "CreateModelMonitorOperationMetadata",
    "CreateModelMonitorRequest",
    "DeleteModelMonitoringJobRequest",
    "DeleteModelMonitorRequest",
    "GetModelMonitoringJobRequest",
    "GetModelMonitorRequest",
    "ListModelMonitoringJobsRequest",
    "ListModelMonitoringJobsResponse",
    "ListModelMonitorsRequest",
    "ListModelMonitorsResponse",
    "SearchModelMonitoringAlertsRequest",
    "SearchModelMonitoringAlertsResponse",
    "SearchModelMonitoringStatsRequest",
    "SearchModelMonitoringStatsResponse",
    "UpdateModelMonitorOperationMetadata",
    "UpdateModelMonitorRequest",
    "ModelMonitoringInput",
    "ModelMonitoringNotificationSpec",
    "ModelMonitoringObjectiveSpec",
    "ModelMonitoringOutputSpec",
    "ModelMonitoringSpec",
    "ModelMonitoringStats",
    "ModelMonitoringStatsDataPoint",
    "ModelMonitoringTabularStats",
    "SearchModelMonitoringStatsFilter",
    "BatchImportEvaluatedAnnotationsRequest",
    "BatchImportEvaluatedAnnotationsResponse",
    "BatchImportModelEvaluationSlicesRequest",
    "BatchImportModelEvaluationSlicesResponse",
    "CopyModelOperationMetadata",
    "CopyModelRequest",
    "CopyModelResponse",
    "DeleteModelRequest",
    "DeleteModelVersionRequest",
    "ExportModelOperationMetadata",
    "ExportModelRequest",
    "ExportModelResponse",
    "GetModelEvaluationRequest",
    "GetModelEvaluationSliceRequest",
    "GetModelRequest",
    "ImportModelEvaluationRequest",
    "ListModelEvaluationSlicesRequest",
    "ListModelEvaluationSlicesResponse",
    "ListModelEvaluationsRequest",
    "ListModelEvaluationsResponse",
    "ListModelsRequest",
    "ListModelsResponse",
    "ListModelVersionCheckpointsRequest",
    "ListModelVersionCheckpointsResponse",
    "ListModelVersionsRequest",
    "ListModelVersionsResponse",
    "MergeVersionAliasesRequest",
    "ModelVersionCheckpoint",
    "RecommendSpecRequest",
    "RecommendSpecResponse",
    "UpdateExplanationDatasetOperationMetadata",
    "UpdateExplanationDatasetRequest",
    "UpdateExplanationDatasetResponse",
    "UpdateModelRequest",
    "UploadModelOperationMetadata",
    "UploadModelRequest",
    "UploadModelResponse",
    "NasJob",
    "NasJobOutput",
    "NasJobSpec",
    "NasTrial",
    "NasTrialDetail",
    "NetworkSpec",
    "NotebookEucConfig",
    "NotebookExecutionJob",
    "NotebookIdleShutdownConfig",
    "NotebookRuntime",
    "NotebookRuntimeTemplate",
    "NotebookRuntimeType",
    "NotebookRuntimeTemplateRef",
    "AssignNotebookRuntimeOperationMetadata",
    "AssignNotebookRuntimeRequest",
    "CreateNotebookExecutionJobOperationMetadata",
    "CreateNotebookExecutionJobRequest",
    "CreateNotebookRuntimeTemplateOperationMetadata",
    "CreateNotebookRuntimeTemplateRequest",
    "DeleteNotebookExecutionJobRequest",
    "DeleteNotebookRuntimeRequest",
    "DeleteNotebookRuntimeTemplateRequest",
    "GetNotebookExecutionJobRequest",
    "GetNotebookRuntimeRequest",
    "GetNotebookRuntimeTemplateRequest",
    "ListNotebookExecutionJobsRequest",
    "ListNotebookExecutionJobsResponse",
    "ListNotebookRuntimesRequest",
    "ListNotebookRuntimesResponse",
    "ListNotebookRuntimeTemplatesRequest",
    "ListNotebookRuntimeTemplatesResponse",
    "StartNotebookRuntimeOperationMetadata",
    "StartNotebookRuntimeRequest",
    "StartNotebookRuntimeResponse",
    "StopNotebookRuntimeOperationMetadata",
    "StopNotebookRuntimeRequest",
    "StopNotebookRuntimeResponse",
    "UpdateNotebookRuntimeTemplateRequest",
    "UpgradeNotebookRuntimeOperationMetadata",
    "UpgradeNotebookRuntimeRequest",
    "UpgradeNotebookRuntimeResponse",
    "NotebookExecutionJobView",
    "ColabImage",
    "NotebookSoftwareConfig",
    "PostStartupScriptConfig",
    "Schema",
    "Type",
    "DeleteOperationMetadata",
    "GenericOperationMetadata",
    "PersistentResource",
    "RayLogsSpec",
    "RayMetricSpec",
    "RaySpec",
    "ResourcePool",
    "ResourceRuntime",
    "ResourceRuntimeSpec",
    "ServiceAccountSpec",
    "CreatePersistentResourceOperationMetadata",
    "CreatePersistentResourceRequest",
    "DeletePersistentResourceRequest",
    "GetPersistentResourceRequest",
    "ListPersistentResourcesRequest",
    "ListPersistentResourcesResponse",
    "RebootPersistentResourceOperationMetadata",
    "RebootPersistentResourceRequest",
    "UpdatePersistentResourceOperationMetadata",
    "UpdatePersistentResourceRequest",
    "PipelineFailurePolicy",
    "PipelineJob",
    "PipelineJobDetail",
    "PipelineTaskDetail",
    "PipelineTaskExecutorDetail",
    "PipelineTaskRerunConfig",
    "PipelineTemplateMetadata",
    "BatchCancelPipelineJobsOperationMetadata",
    "BatchCancelPipelineJobsRequest",
    "BatchCancelPipelineJobsResponse",
    "BatchDeletePipelineJobsRequest",
    "BatchDeletePipelineJobsResponse",
    "CancelPipelineJobRequest",
    "CancelTrainingPipelineRequest",
    "CreatePipelineJobRequest",
    "CreateTrainingPipelineRequest",
    "DeletePipelineJobRequest",
    "DeleteTrainingPipelineRequest",
    "GetPipelineJobRequest",
    "GetTrainingPipelineRequest",
    "ListPipelineJobsRequest",
    "ListPipelineJobsResponse",
    "ListTrainingPipelinesRequest",
    "ListTrainingPipelinesResponse",
    "PipelineState",
    "ChatCompletionsRequest",
    "CountTokensRequest",
    "CountTokensResponse",
    "DirectPredictRequest",
    "DirectPredictResponse",
    "DirectRawPredictRequest",
    "DirectRawPredictResponse",
    "EmbedContentRequest",
    "EmbedContentResponse",
    "ExplainRequest",
    "ExplainResponse",
    "GenerateContentRequest",
    "GenerateContentResponse",
    "GenerateVideoResponse",
    "PredictLongRunningMetadata",
    "PredictLongRunningResponse",
    "PredictRequest",
    "PredictResponse",
    "RawPredictRequest",
    "StreamDirectPredictRequest",
    "StreamDirectPredictResponse",
    "StreamDirectRawPredictRequest",
    "StreamDirectRawPredictResponse",
    "StreamingPredictRequest",
    "StreamingPredictResponse",
    "StreamingRawPredictRequest",
    "StreamingRawPredictResponse",
    "StreamRawPredictRequest",
    "PublisherModel",
    "ReasoningEngine",
    "ReasoningEngineContextSpec",
    "ReasoningEngineSpec",
    "QueryReasoningEngineRequest",
    "QueryReasoningEngineResponse",
    "StreamQueryReasoningEngineRequest",
    "CreateReasoningEngineOperationMetadata",
    "CreateReasoningEngineRequest",
    "DeleteReasoningEngineRequest",
    "GetReasoningEngineRequest",
    "ListReasoningEnginesRequest",
    "ListReasoningEnginesResponse",
    "UpdateReasoningEngineOperationMetadata",
    "UpdateReasoningEngineRequest",
    "ReservationAffinity",
    "SavedQuery",
    "Schedule",
    "CreateScheduleRequest",
    "DeleteScheduleRequest",
    "GetScheduleRequest",
    "ListSchedulesRequest",
    "ListSchedulesResponse",
    "PauseScheduleRequest",
    "ResumeScheduleRequest",
    "UpdateScheduleRequest",
    "DnsPeeringConfig",
    "PrivateServiceConnectConfig",
    "PscAutomatedEndpoints",
    "PSCAutomationConfig",
    "PscInterfaceConfig",
    "PSCAutomationState",
    "EventActions",
    "EventMetadata",
    "Session",
    "SessionEvent",
    "AppendEventRequest",
    "AppendEventResponse",
    "CreateSessionOperationMetadata",
    "CreateSessionRequest",
    "DeleteSessionRequest",
    "GetSessionRequest",
    "ListEventsRequest",
    "ListEventsResponse",
    "ListSessionsRequest",
    "ListSessionsResponse",
    "UpdateSessionRequest",
    "SpecialistPool",
    "CreateSpecialistPoolOperationMetadata",
    "CreateSpecialistPoolRequest",
    "DeleteSpecialistPoolRequest",
    "GetSpecialistPoolRequest",
    "ListSpecialistPoolsRequest",
    "ListSpecialistPoolsResponse",
    "UpdateSpecialistPoolOperationMetadata",
    "UpdateSpecialistPoolRequest",
    "Measurement",
    "Study",
    "StudySpec",
    "StudyTimeConstraint",
    "Trial",
    "TrialContext",
    "Tensorboard",
    "Scalar",
    "TensorboardBlob",
    "TensorboardBlobSequence",
    "TensorboardTensor",
    "TimeSeriesData",
    "TimeSeriesDataPoint",
    "TensorboardExperiment",
    "TensorboardRun",
    "BatchCreateTensorboardRunsRequest",
    "BatchCreateTensorboardRunsResponse",
    "BatchCreateTensorboardTimeSeriesRequest",
    "BatchCreateTensorboardTimeSeriesResponse",
    "BatchReadTensorboardTimeSeriesDataRequest",
    "BatchReadTensorboardTimeSeriesDataResponse",
    "CreateTensorboardExperimentRequest",
    "CreateTensorboardOperationMetadata",
    "CreateTensorboardRequest",
    "CreateTensorboardRunRequest",
    "CreateTensorboardTimeSeriesRequest",
    "DeleteTensorboardExperimentRequest",
    "DeleteTensorboardRequest",
    "DeleteTensorboardRunRequest",
    "DeleteTensorboardTimeSeriesRequest",
    "ExportTensorboardTimeSeriesDataRequest",
    "ExportTensorboardTimeSeriesDataResponse",
    "GetTensorboardExperimentRequest",
    "GetTensorboardRequest",
    "GetTensorboardRunRequest",
    "GetTensorboardTimeSeriesRequest",
    "ListTensorboardExperimentsRequest",
    "ListTensorboardExperimentsResponse",
    "ListTensorboardRunsRequest",
    "ListTensorboardRunsResponse",
    "ListTensorboardsRequest",
    "ListTensorboardsResponse",
    "ListTensorboardTimeSeriesRequest",
    "ListTensorboardTimeSeriesResponse",
    "ReadTensorboardBlobDataRequest",
    "ReadTensorboardBlobDataResponse",
    "ReadTensorboardSizeRequest",
    "ReadTensorboardSizeResponse",
    "ReadTensorboardTimeSeriesDataRequest",
    "ReadTensorboardTimeSeriesDataResponse",
    "ReadTensorboardUsageRequest",
    "ReadTensorboardUsageResponse",
    "UpdateTensorboardExperimentRequest",
    "UpdateTensorboardOperationMetadata",
    "UpdateTensorboardRequest",
    "UpdateTensorboardRunRequest",
    "UpdateTensorboardTimeSeriesRequest",
    "WriteTensorboardExperimentDataRequest",
    "WriteTensorboardExperimentDataResponse",
    "WriteTensorboardRunDataRequest",
    "WriteTensorboardRunDataResponse",
    "TensorboardTimeSeries",
    "CodeExecutionResult",
    "DynamicRetrievalConfig",
    "EnterpriseWebSearch",
    "ExecutableCode",
    "FunctionCall",
    "FunctionCallingConfig",
    "FunctionDeclaration",
    "FunctionResponse",
    "FunctionResponseBlob",
    "FunctionResponseFileData",
    "FunctionResponsePart",
    "GoogleMaps",
    "GoogleSearchRetrieval",
    "RagRetrievalConfig",
    "Retrieval",
    "RetrievalConfig",
    "Tool",
    "ToolConfig",
    "ToolUseExample",
    "UrlContext",
    "VertexAISearch",
    "VertexRagStore",
    "FilterSplit",
    "FractionSplit",
    "InputDataConfig",
    "PredefinedSplit",
    "StratifiedSplit",
    "TimestampSplit",
    "TrainingPipeline",
    "DatasetDistribution",
    "DatasetStats",
    "DistillationDataStats",
    "DistillationHyperParameters",
    "DistillationSpec",
    "EvaluateDatasetRun",
    "EvaluationConfig",
    "PartnerModelTuningSpec",
    "PreTunedModel",
    "SupervisedHyperParameters",
    "SupervisedTuningDatasetDistribution",
    "SupervisedTuningDataStats",
    "SupervisedTuningSpec",
    "TunedModel",
    "TunedModelCheckpoint",
    "TunedModelRef",
    "TuningDataStats",
    "TuningJob",
    "VeoHyperParameters",
    "VeoTuningSpec",
    "BoolArray",
    "DoubleArray",
    "Int64Array",
    "StringArray",
    "Tensor",
    "ArtifactTypeSchema",
    "RuntimeArtifact",
    "UnmanagedContainerModel",
    "UsageMetadata",
    "UserActionReference",
    "Value",
    "CorpusStatus",
    "FileStatus",
    "ImportRagFilesConfig",
    "RagChunk",
    "RagCorpus",
    "RagEmbeddingModelConfig",
    "RagEngineConfig",
    "RagFile",
    "RagFileChunkingConfig",
    "RagFileMetadataConfig",
    "RagFileParsingConfig",
    "RagFileTransformationConfig",
    "RagManagedDbConfig",
    "RagVectorDbConfig",
    "UploadRagFileConfig",
    "VertexAiSearchConfig",
    "CreateRagCorpusOperationMetadata",
    "CreateRagCorpusRequest",
    "DeleteRagCorpusRequest",
    "DeleteRagFileRequest",
    "GetRagCorpusRequest",
    "GetRagEngineConfigRequest",
    "GetRagFileRequest",
    "ImportRagFilesOperationMetadata",
    "ImportRagFilesRequest",
    "ImportRagFilesResponse",
    "ListRagCorporaRequest",
    "ListRagCorporaResponse",
    "ListRagFilesRequest",
    "ListRagFilesResponse",
    "UpdateRagCorpusOperationMetadata",
    "UpdateRagCorpusRequest",
    "UpdateRagEngineConfigOperationMetadata",
    "UpdateRagEngineConfigRequest",
    "UploadRagFileRequest",
    "UploadRagFileResponse",
    "AugmentPromptRequest",
    "AugmentPromptResponse",
    "Claim",
    "CorroborateContentRequest",
    "CorroborateContentResponse",
    "Fact",
    "RagContexts",
    "RagQuery",
    "RetrieveContextsRequest",
    "RetrieveContextsResponse",
    "AddTrialMeasurementRequest",
    "CheckTrialEarlyStoppingStateMetatdata",
    "CheckTrialEarlyStoppingStateRequest",
    "CheckTrialEarlyStoppingStateResponse",
    "CompleteTrialRequest",
    "CreateStudyRequest",
    "CreateTrialRequest",
    "DeleteStudyRequest",
    "DeleteTrialRequest",
    "GetStudyRequest",
    "GetTrialRequest",
    "ListOptimalTrialsRequest",
    "ListOptimalTrialsResponse",
    "ListStudiesRequest",
    "ListStudiesResponse",
    "ListTrialsRequest",
    "ListTrialsResponse",
    "LookupStudyRequest",
    "StopTrialRequest",
    "SuggestTrialsMetadata",
    "SuggestTrialsRequest",
    "SuggestTrialsResponse",
)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import json
import logging as std_logging
import pickle
import warnings
from typing import Callable, Dict, Optional, Sequence, Tuple, Union

from google.api_core import grpc_helpers
from google.api_core import operations_v1
from google.api_core import gapic_v1
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.auth.transport.grpc import SslCredentials  # type: ignore
from google.protobuf.json_format import MessageToJson
import google.protobuf.message

import grpc  # type: ignore
import proto  # type: ignore

from google.cloud.logging_v2.types import logging_config
from google.longrunning import operations_pb2  # type: ignore
from google.protobuf import empty_pb2  # type: ignore
from .base import ConfigServiceV2Transport, DEFAULT_CLIENT_INFO

try:
    from google.api_core import client_logging  # type: ignore

    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
except ImportError:  # pragma: NO COVER
    CLIENT_LOGGING_SUPPORTED = False

_LOGGER = std_logging.getLogger(__name__)


class _LoggingClientInterceptor(grpc.UnaryUnaryClientInterceptor):  # pragma: NO COVER
    def intercept_unary_unary(self, continuation, client_call_details, request):
        logging_enabled = CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
            std_logging.DEBUG
        )
        if logging_enabled:  # pragma: NO COVER
            request_metadata = client_call_details.metadata
            if isinstance(request, proto.Message):
                request_payload = type(request).to_json(request)
            elif isinstance(request, google.protobuf.message.Message):
                request_payload = MessageToJson(request)
            else:
                request_payload = f"{type(request).__name__}: {pickle.dumps(request)}"

            request_metadata = {
                key: value.decode("utf-8") if isinstance(value, bytes) else value
                for key, value in request_metadata
            }
            grpc_request = {
                "payload": request_payload,
                "requestMethod": "grpc",
                "metadata": dict(request_metadata),
            }
            _LOGGER.debug(
                f"Sending request for {client_call_details.method}",
                extra={
                    "serviceName": "google.logging.v2.ConfigServiceV2",
                    "rpcName": str(client_call_details.method),
                    "request": grpc_request,
                    "metadata": grpc_request["metadata"],
                },
            )
        response = continuation(client_call_details, request)
        if logging_enabled:  # pragma: NO COVER
            response_metadata = response.trailing_metadata()
            # Convert gRPC metadata `<class 'grpc.aio._metadata.Metadata'>` to list of tuples
            metadata = (
                dict([(k, str(v)) for k, v in response_metadata])
                if response_metadata
                else None
            )
            result = response.result()
            if isinstance(result, proto.Message):
                response_payload = type(result).to_json(result)
            elif isinstance(result, google.protobuf.message.Message):
                response_payload = MessageToJson(result)
            else:
                response_payload = f"{type(result).__name__}: {pickle.dumps(result)}"
            grpc_response = {
                "payload": response_payload,
                "metadata": metadata,
                "status": "OK",
            }
            _LOGGER.debug(
                f"Received response for {client_call_details.method}.",
                extra={
                    "serviceName": "google.logging.v2.ConfigServiceV2",
                    "rpcName": client_call_details.method,
                    "response": grpc_response,
                    "metadata": grpc_response["metadata"],
                },
            )
        return response


class ConfigServiceV2GrpcTransport(ConfigServiceV2Transport):
    """gRPC backend transport for ConfigServiceV2.

    Service for configuring sinks used to route log entries.

    This class defines the same methods as the primary client, so the
    primary client can load the underlying transport implementation
    and call it.

    It sends protocol buffers over the wire using gRPC (which is built on
    top of HTTP/2); the ``grpcio`` package must be installed.
    """

    _stubs: Dict[str, Callable]

    def __init__(
        self,
        *,
        host: str = "logging.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        channel: Optional[Union[grpc.Channel, Callable[..., grpc.Channel]]] = None,
        api_mtls_endpoint: Optional[str] = None,
        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'logging.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is ignored if a ``channel`` instance is provided.
            credentials_file (Optional[str]): Deprecated. A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is ignored if a ``channel`` instance is provided.
                This argument will be removed in the next major version of this library.
            scopes (Optional(Sequence[str])): A list of scopes. This argument is
                ignored if a ``channel`` instance is provided.
            channel (Optional[Union[grpc.Channel, Callable[..., grpc.Channel]]]):
                A ``Channel`` instance through which to make calls, or a Callable
                that constructs and returns one. If set to None, ``self.create_channel``
                is used to create the channel. If a Callable is given, it will be called
                with the same arguments as used in ``self.create_channel``.
            api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                If provided, it overrides the ``host`` argument and tries to create
                a mutual TLS channel with client SSL credentials from
                ``client_cert_source`` or application default SSL credentials.
            client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                Deprecated. A callback to provide client SSL certificate bytes and
                private key bytes, both in PEM format. It is ignored if
                ``api_mtls_endpoint`` is None.
            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
                for the grpc channel. It is ignored if a ``channel`` instance is provided.
            client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                A callback to provide client certificate bytes and private key bytes,
                both in PEM format. It is used to configure a mutual TLS channel. It is
                ignored if a ``channel`` instance or ``ssl_channel_credentials`` is provided.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.

        Raises:
          google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
              creation failed for any reason.
          google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
              and ``credentials_file`` are passed.
        """
        self._grpc_channel = None
        self._ssl_channel_credentials = ssl_channel_credentials
        self._stubs: Dict[str, Callable] = {}
        self._operations_client: Optional[operations_v1.OperationsClient] = None

        if api_mtls_endpoint:
            warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
        if client_cert_source:
            warnings.warn("client_cert_source is deprecated", DeprecationWarning)

        if isinstance(channel, grpc.Channel):
            # Ignore credentials if a channel was passed.
            credentials = None
            self._ignore_credentials = True
            # If a channel was explicitly provided, set it.
            self._grpc_channel = channel
            self._ssl_channel_credentials = None

        else:
            if api_mtls_endpoint:
                host = api_mtls_endpoint

                # Create SSL credentials with client_cert_source or application
                # default SSL credentials.
                if client_cert_source:
                    cert, key = client_cert_source()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )
                else:
                    self._ssl_channel_credentials = SslCredentials().ssl_credentials

            else:
                if client_cert_source_for_mtls and not ssl_channel_credentials:
                    cert, key = client_cert_source_for_mtls()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )

        # The base transport sets the host, credentials and scopes
        super().__init__(
            host=host,
            credentials=credentials,
            credentials_file=credentials_file,
            scopes=scopes,
            quota_project_id=quota_project_id,
            client_info=client_info,
            always_use_jwt_access=always_use_jwt_access,
            api_audience=api_audience,
        )

        if not self._grpc_channel:
            # initialize with the provided callable or the default channel
            channel_init = channel or type(self).create_channel
            self._grpc_channel = channel_init(
                self._host,
                # use the credentials which are saved
                credentials=self._credentials,
                # Set ``credentials_file`` to ``None`` here as
                # the credentials that we saved earlier should be used.
                credentials_file=None,
                scopes=self._scopes,
                ssl_credentials=self._ssl_channel_credentials,
                quota_project_id=quota_project_id,
                options=[
                    ("grpc.max_send_message_length", -1),
                    ("grpc.max_receive_message_length", -1),
                ],
            )

        self._interceptor = _LoggingClientInterceptor()
        self._logged_channel = grpc.intercept_channel(
            self._grpc_channel, self._interceptor
        )

        # Wrap messages. This must be done after self._logged_channel exists
        self._prep_wrapped_messages(client_info)

    @classmethod
    def create_channel(
        cls,
        host: str = "logging.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        **kwargs,
    ) -> grpc.Channel:
        """Create and return a gRPC channel object.
        Args:
            host (Optional[str]): The host for the channel to use.
            credentials (Optional[~.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            credentials_file (Optional[str]): Deprecated. A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.  This argument will be
                removed in the next major version of this library.
            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                service. These are only used when credentials are not specified and
                are passed to :func:`google.auth.default`.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            kwargs (Optional[dict]): Keyword arguments, which are passed to the
                channel creation.
        Returns:
            grpc.Channel: A gRPC channel object.

        Raises:
            google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
              and ``credentials_file`` are passed.
        """

        return grpc_helpers.create_channel(
            host,
            credentials=credentials,
            credentials_file=credentials_file,
            quota_project_id=quota_project_id,
            default_scopes=cls.AUTH_SCOPES,
            scopes=scopes,
            default_host=cls.DEFAULT_HOST,
            **kwargs,
        )

    @property
    def grpc_channel(self) -> grpc.Channel:
        """Return the channel designed to connect to this service."""
        return self._grpc_channel

    @property
    def operations_client(self) -> operations_v1.OperationsClient:
        """Create the client designed to process long-running operations.

        This property caches on the instance; repeated calls return the same
        client.
        """
        # Quick check: Only create a new client if we do not already have one.
        if self._operations_client is None:
            self._operations_client = operations_v1.OperationsClient(
                self._logged_channel
            )

        # Return the client from cache.
        return self._operations_client

    @property
    def list_buckets(
        self,
    ) -> Callable[
        [logging_config.ListBucketsRequest], logging_config.ListBucketsResponse
    ]:
        r"""Return a callable for the list buckets method over gRPC.

        Lists log buckets.

        Returns:
            Callable[[~.ListBucketsRequest],
                    ~.ListBucketsResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_buckets" not in self._stubs:
            self._stubs["list_buckets"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/ListBuckets",
                request_serializer=logging_config.ListBucketsRequest.serialize,
                response_deserializer=logging_config.ListBucketsResponse.deserialize,
            )
        return self._stubs["list_buckets"]

    @property
    def get_bucket(
        self,
    ) -> Callable[[logging_config.GetBucketRequest], logging_config.LogBucket]:
        r"""Return a callable for the get bucket method over gRPC.

        Gets a log bucket.

        Returns:
            Callable[[~.GetBucketRequest],
                    ~.LogBucket]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_bucket" not in self._stubs:
            self._stubs["get_bucket"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/GetBucket",
                request_serializer=logging_config.GetBucketRequest.serialize,
                response_deserializer=logging_config.LogBucket.deserialize,
            )
        return self._stubs["get_bucket"]

    @property
    def create_bucket_async(
        self,
    ) -> Callable[[logging_config.CreateBucketRequest], operations_pb2.Operation]:
        r"""Return a callable for the create bucket async method over gRPC.

        Creates a log bucket asynchronously that can be used
        to store log entries.
        After a bucket has been created, the bucket's location
        cannot be changed.

        Returns:
            Callable[[~.CreateBucketRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_bucket_async" not in self._stubs:
            self._stubs["create_bucket_async"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/CreateBucketAsync",
                request_serializer=logging_config.CreateBucketRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_bucket_async"]

    @property
    def update_bucket_async(
        self,
    ) -> Callable[[logging_config.UpdateBucketRequest], operations_pb2.Operation]:
        r"""Return a callable for the update bucket async method over gRPC.

        Updates a log bucket asynchronously.

        If the bucket has a ``lifecycle_state`` of ``DELETE_REQUESTED``,
        then ``FAILED_PRECONDITION`` will be returned.

        After a bucket has been created, the bucket's location cannot be
        changed.

        Returns:
            Callable[[~.UpdateBucketRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_bucket_async" not in self._stubs:
            self._stubs["update_bucket_async"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/UpdateBucketAsync",
                request_serializer=logging_config.UpdateBucketRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_bucket_async"]

    @property
    def create_bucket(
        self,
    ) -> Callable[[logging_config.CreateBucketRequest], logging_config.LogBucket]:
        r"""Return a callable for the create bucket method over gRPC.

        Creates a log bucket that can be used to store log
        entries. After a bucket has been created, the bucket's
        location cannot be changed.

        Returns:
            Callable[[~.CreateBucketRequest],
                    ~.LogBucket]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_bucket" not in self._stubs:
            self._stubs["create_bucket"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/CreateBucket",
                request_serializer=logging_config.CreateBucketRequest.serialize,
                response_deserializer=logging_config.LogBucket.deserialize,
            )
        return self._stubs["create_bucket"]

    @property
    def update_bucket(
        self,
    ) -> Callable[[logging_config.UpdateBucketRequest], logging_config.LogBucket]:
        r"""Return a callable for the update bucket method over gRPC.

        Updates a log bucket.

        If the bucket has a ``lifecycle_state`` of ``DELETE_REQUESTED``,
        then ``FAILED_PRECONDITION`` will be returned.

        After a bucket has been created, the bucket's location cannot be
        changed.

        Returns:
            Callable[[~.UpdateBucketRequest],
                    ~.LogBucket]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_bucket" not in self._stubs:
            self._stubs["update_bucket"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/UpdateBucket",
                request_serializer=logging_config.UpdateBucketRequest.serialize,
                response_deserializer=logging_config.LogBucket.deserialize,
            )
        return self._stubs["update_bucket"]

    @property
    def delete_bucket(
        self,
    ) -> Callable[[logging_config.DeleteBucketRequest], empty_pb2.Empty]:
        r"""Return a callable for the delete bucket method over gRPC.

        Deletes a log bucket.

        Changes the bucket's ``lifecycle_state`` to the
        ``DELETE_REQUESTED`` state. After 7 days, the bucket will be
        purged and all log entries in the bucket will be permanently
        deleted.

        Returns:
            Callable[[~.DeleteBucketRequest],
                    ~.Empty]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_bucket" not in self._stubs:
            self._stubs["delete_bucket"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/DeleteBucket",
                request_serializer=logging_config.DeleteBucketRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_bucket"]

    @property
    def undelete_bucket(
        self,
    ) -> Callable[[logging_config.UndeleteBucketRequest], empty_pb2.Empty]:
        r"""Return a callable for the undelete bucket method over gRPC.

        Undeletes a log bucket. A bucket that has been
        deleted can be undeleted within the grace period of 7
        days.

        Returns:
            Callable[[~.UndeleteBucketRequest],
                    ~.Empty]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "undelete_bucket" not in self._stubs:
            self._stubs["undelete_bucket"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/UndeleteBucket",
                request_serializer=logging_config.UndeleteBucketRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["undelete_bucket"]

    @property
    def list_views(
        self,
    ) -> Callable[[logging_config.ListViewsRequest], logging_config.ListViewsResponse]:
        r"""Return a callable for the list views method over gRPC.

        Lists views on a log bucket.

        Returns:
            Callable[[~.ListViewsRequest],
                    ~.ListViewsResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_views" not in self._stubs:
            self._stubs["list_views"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/ListViews",
                request_serializer=logging_config.ListViewsRequest.serialize,
                response_deserializer=logging_config.ListViewsResponse.deserialize,
            )
        return self._stubs["list_views"]

    @property
    def get_view(
        self,
    ) -> Callable[[logging_config.GetViewRequest], logging_config.LogView]:
        r"""Return a callable for the get view method over gRPC.

        Gets a view on a log bucket..

        Returns:
            Callable[[~.GetViewRequest],
                    ~.LogView]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_view" not in self._stubs:
            self._stubs["get_view"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/GetView",
                request_serializer=logging_config.GetViewRequest.serialize,
                response_deserializer=logging_config.LogView.deserialize,
            )
        return self._stubs["get_view"]

    @property
    def create_view(
        self,
    ) -> Callable[[logging_config.CreateViewRequest], logging_config.LogView]:
        r"""Return a callable for the create view method over gRPC.

        Creates a view over log entries in a log bucket. A
        bucket may contain a maximum of 30 views.

        Returns:
            Callable[[~.CreateViewRequest],
                    ~.LogView]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_view" not in self._stubs:
            self._stubs["create_view"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/CreateView",
                request_serializer=logging_config.CreateViewRequest.serialize,
                response_deserializer=logging_config.LogView.deserialize,
            )
        return self._stubs["create_view"]

    @property
    def update_view(
        self,
    ) -> Callable[[logging_config.UpdateViewRequest], logging_config.LogView]:
        r"""Return a callable for the update view method over gRPC.

        Updates a view on a log bucket. This method replaces the
        following fields in the existing view with values from the new
        view: ``filter``. If an ``UNAVAILABLE`` error is returned, this
        indicates that system is not in a state where it can update the
        view. If this occurs, please try again in a few minutes.

        Returns:
            Callable[[~.UpdateViewRequest],
                    ~.LogView]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_view" not in self._stubs:
            self._stubs["update_view"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/UpdateView",
                request_serializer=logging_config.UpdateViewRequest.serialize,
                response_deserializer=logging_config.LogView.deserialize,
            )
        return self._stubs["update_view"]

    @property
    def delete_view(
        self,
    ) -> Callable[[logging_config.DeleteViewRequest], empty_pb2.Empty]:
        r"""Return a callable for the delete view method over gRPC.

        Deletes a view on a log bucket. If an ``UNAVAILABLE`` error is
        returned, this indicates that system is not in a state where it
        can delete the view. If this occurs, please try again in a few
        minutes.

        Returns:
            Callable[[~.DeleteViewRequest],
                    ~.Empty]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_view" not in self._stubs:
            self._stubs["delete_view"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/DeleteView",
                request_serializer=logging_config.DeleteViewRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_view"]

    @property
    def list_sinks(
        self,
    ) -> Callable[[logging_config.ListSinksRequest], logging_config.ListSinksResponse]:
        r"""Return a callable for the list sinks method over gRPC.

        Lists sinks.

        Returns:
            Callable[[~.ListSinksRequest],
                    ~.ListSinksResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_sinks" not in self._stubs:
            self._stubs["list_sinks"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/ListSinks",
                request_serializer=logging_config.ListSinksRequest.serialize,
                response_deserializer=logging_config.ListSinksResponse.deserialize,
            )
        return self._stubs["list_sinks"]

    @property
    def get_sink(
        self,
    ) -> Callable[[logging_config.GetSinkRequest], logging_config.LogSink]:
        r"""Return a callable for the get sink method over gRPC.

        Gets a sink.

        Returns:
            Callable[[~.GetSinkRequest],
                    ~.LogSink]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_sink" not in self._stubs:
            self._stubs["get_sink"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/GetSink",
                request_serializer=logging_config.GetSinkRequest.serialize,
                response_deserializer=logging_config.LogSink.deserialize,
            )
        return self._stubs["get_sink"]

    @property
    def create_sink(
        self,
    ) -> Callable[[logging_config.CreateSinkRequest], logging_config.LogSink]:
        r"""Return a callable for the create sink method over gRPC.

        Creates a sink that exports specified log entries to a
        destination. The export of newly-ingested log entries begins
        immediately, unless the sink's ``writer_identity`` is not
        permitted to write to the destination. A sink can export log
        entries only from the resource owning the sink.

        Returns:
            Callable[[~.CreateSinkRequest],
                    ~.LogSink]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_sink" not in self._stubs:
            self._stubs["create_sink"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/CreateSink",
                request_serializer=logging_config.CreateSinkRequest.serialize,
                response_deserializer=logging_config.LogSink.deserialize,
            )
        return self._stubs["create_sink"]

    @property
    def update_sink(
        self,
    ) -> Callable[[logging_config.UpdateSinkRequest], logging_config.LogSink]:
        r"""Return a callable for the update sink method over gRPC.

        Updates a sink. This method replaces the following fields in the
        existing sink with values from the new sink: ``destination``,
        and ``filter``.

        The updated sink might also have a new ``writer_identity``; see
        the ``unique_writer_identity`` field.

        Returns:
            Callable[[~.UpdateSinkRequest],
                    ~.LogSink]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_sink" not in self._stubs:
            self._stubs["update_sink"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/UpdateSink",
                request_serializer=logging_config.UpdateSinkRequest.serialize,
                response_deserializer=logging_config.LogSink.deserialize,
            )
        return self._stubs["update_sink"]

    @property
    def delete_sink(
        self,
    ) -> Callable[[logging_config.DeleteSinkRequest], empty_pb2.Empty]:
        r"""Return a callable for the delete sink method over gRPC.

        Deletes a sink. If the sink has a unique ``writer_identity``,
        then that service account is also deleted.

        Returns:
            Callable[[~.DeleteSinkRequest],
                    ~.Empty]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_sink" not in self._stubs:
            self._stubs["delete_sink"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/DeleteSink",
                request_serializer=logging_config.DeleteSinkRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_sink"]

    @property
    def create_link(
        self,
    ) -> Callable[[logging_config.CreateLinkRequest], operations_pb2.Operation]:
        r"""Return a callable for the create link method over gRPC.

        Asynchronously creates a linked dataset in BigQuery
        which makes it possible to use BigQuery to read the logs
        stored in the log bucket. A log bucket may currently
        only contain one link.

        Returns:
            Callable[[~.CreateLinkRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_link" not in self._stubs:
            self._stubs["create_link"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/CreateLink",
                request_serializer=logging_config.CreateLinkRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_link"]

    @property
    def delete_link(
        self,
    ) -> Callable[[logging_config.DeleteLinkRequest], operations_pb2.Operation]:
        r"""Return a callable for the delete link method over gRPC.

        Deletes a link. This will also delete the
        corresponding BigQuery linked dataset.

        Returns:
            Callable[[~.DeleteLinkRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_link" not in self._stubs:
            self._stubs["delete_link"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/DeleteLink",
                request_serializer=logging_config.DeleteLinkRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["delete_link"]

    @property
    def list_links(
        self,
    ) -> Callable[[logging_config.ListLinksRequest], logging_config.ListLinksResponse]:
        r"""Return a callable for the list links method over gRPC.

        Lists links.

        Returns:
            Callable[[~.ListLinksRequest],
                    ~.ListLinksResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_links" not in self._stubs:
            self._stubs["list_links"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/ListLinks",
                request_serializer=logging_config.ListLinksRequest.serialize,
                response_deserializer=logging_config.ListLinksResponse.deserialize,
            )
        return self._stubs["list_links"]

    @property
    def get_link(
        self,
    ) -> Callable[[logging_config.GetLinkRequest], logging_config.Link]:
        r"""Return a callable for the get link method over gRPC.

        Gets a link.

        Returns:
            Callable[[~.GetLinkRequest],
                    ~.Link]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_link" not in self._stubs:
            self._stubs["get_link"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/GetLink",
                request_serializer=logging_config.GetLinkRequest.serialize,
                response_deserializer=logging_config.Link.deserialize,
            )
        return self._stubs["get_link"]

    @property
    def list_exclusions(
        self,
    ) -> Callable[
        [logging_config.ListExclusionsRequest], logging_config.ListExclusionsResponse
    ]:
        r"""Return a callable for the list exclusions method over gRPC.

        Lists all the exclusions on the \_Default sink in a parent
        resource.

        Returns:
            Callable[[~.ListExclusionsRequest],
                    ~.ListExclusionsResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_exclusions" not in self._stubs:
            self._stubs["list_exclusions"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/ListExclusions",
                request_serializer=logging_config.ListExclusionsRequest.serialize,
                response_deserializer=logging_config.ListExclusionsResponse.deserialize,
            )
        return self._stubs["list_exclusions"]

    @property
    def get_exclusion(
        self,
    ) -> Callable[[logging_config.GetExclusionRequest], logging_config.LogExclusion]:
        r"""Return a callable for the get exclusion method over gRPC.

        Gets the description of an exclusion in the \_Default sink.

        Returns:
            Callable[[~.GetExclusionRequest],
                    ~.LogExclusion]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_exclusion" not in self._stubs:
            self._stubs["get_exclusion"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/GetExclusion",
                request_serializer=logging_config.GetExclusionRequest.serialize,
                response_deserializer=logging_config.LogExclusion.deserialize,
            )
        return self._stubs["get_exclusion"]

    @property
    def create_exclusion(
        self,
    ) -> Callable[[logging_config.CreateExclusionRequest], logging_config.LogExclusion]:
        r"""Return a callable for the create exclusion method over gRPC.

        Creates a new exclusion in the \_Default sink in a specified
        parent resource. Only log entries belonging to that resource can
        be excluded. You can have up to 10 exclusions in a resource.

        Returns:
            Callable[[~.CreateExclusionRequest],
                    ~.LogExclusion]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_exclusion" not in self._stubs:
            self._stubs["create_exclusion"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/CreateExclusion",
                request_serializer=logging_config.CreateExclusionRequest.serialize,
                response_deserializer=logging_config.LogExclusion.deserialize,
            )
        return self._stubs["create_exclusion"]

    @property
    def update_exclusion(
        self,
    ) -> Callable[[logging_config.UpdateExclusionRequest], logging_config.LogExclusion]:
        r"""Return a callable for the update exclusion method over gRPC.

        Changes one or more properties of an existing exclusion in the
        \_Default sink.

        Returns:
            Callable[[~.UpdateExclusionRequest],
                    ~.LogExclusion]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_exclusion" not in self._stubs:
            self._stubs["update_exclusion"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/UpdateExclusion",
                request_serializer=logging_config.UpdateExclusionRequest.serialize,
                response_deserializer=logging_config.LogExclusion.deserialize,
            )
        return self._stubs["update_exclusion"]

    @property
    def delete_exclusion(
        self,
    ) -> Callable[[logging_config.DeleteExclusionRequest], empty_pb2.Empty]:
        r"""Return a callable for the delete exclusion method over gRPC.

        Deletes an exclusion in the \_Default sink.

        Returns:
            Callable[[~.DeleteExclusionRequest],
                    ~.Empty]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_exclusion" not in self._stubs:
            self._stubs["delete_exclusion"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/DeleteExclusion",
                request_serializer=logging_config.DeleteExclusionRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_exclusion"]

    @property
    def get_cmek_settings(
        self,
    ) -> Callable[[logging_config.GetCmekSettingsRequest], logging_config.CmekSettings]:
        r"""Return a callable for the get cmek settings method over gRPC.

        Gets the Logging CMEK settings for the given resource.

        Note: CMEK for the Log Router can be configured for Google Cloud
        projects, folders, organizations and billing accounts. Once
        configured for an organization, it applies to all projects and
        folders in the Google Cloud organization.

        See `Enabling CMEK for Log
        Router <https://cloud.google.com/logging/docs/routing/managed-encryption>`__
        for more information.

        Returns:
            Callable[[~.GetCmekSettingsRequest],
                    ~.CmekSettings]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_cmek_settings" not in self._stubs:
            self._stubs["get_cmek_settings"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/GetCmekSettings",
                request_serializer=logging_config.GetCmekSettingsRequest.serialize,
                response_deserializer=logging_config.CmekSettings.deserialize,
            )
        return self._stubs["get_cmek_settings"]

    @property
    def update_cmek_settings(
        self,
    ) -> Callable[
        [logging_config.UpdateCmekSettingsRequest], logging_config.CmekSettings
    ]:
        r"""Return a callable for the update cmek settings method over gRPC.

        Updates the Log Router CMEK settings for the given resource.

        Note: CMEK for the Log Router can currently only be configured
        for Google Cloud organizations. Once configured, it applies to
        all projects and folders in the Google Cloud organization.

        [UpdateCmekSettings][google.logging.v2.ConfigServiceV2.UpdateCmekSettings]
        will fail if 1) ``kms_key_name`` is invalid, or 2) the
        associated service account does not have the required
        ``roles/cloudkms.cryptoKeyEncrypterDecrypter`` role assigned for
        the key, or 3) access to the key is disabled.

        See `Enabling CMEK for Log
        Router <https://cloud.google.com/logging/docs/routing/managed-encryption>`__
        for more information.

        Returns:
            Callable[[~.UpdateCmekSettingsRequest],
                    ~.CmekSettings]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_cmek_settings" not in self._stubs:
            self._stubs["update_cmek_settings"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/UpdateCmekSettings",
                request_serializer=logging_config.UpdateCmekSettingsRequest.serialize,
                response_deserializer=logging_config.CmekSettings.deserialize,
            )
        return self._stubs["update_cmek_settings"]

    @property
    def get_settings(
        self,
    ) -> Callable[[logging_config.GetSettingsRequest], logging_config.Settings]:
        r"""Return a callable for the get settings method over gRPC.

        Gets the Log Router settings for the given resource.

        Note: Settings for the Log Router can be get for Google Cloud
        projects, folders, organizations and billing accounts. Currently
        it can only be configured for organizations. Once configured for
        an organization, it applies to all projects and folders in the
        Google Cloud organization.

        See `Enabling CMEK for Log
        Router <https://cloud.google.com/logging/docs/routing/managed-encryption>`__
        for more information.

        Returns:
            Callable[[~.GetSettingsRequest],
                    ~.Settings]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_settings" not in self._stubs:
            self._stubs["get_settings"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/GetSettings",
                request_serializer=logging_config.GetSettingsRequest.serialize,
                response_deserializer=logging_config.Settings.deserialize,
            )
        return self._stubs["get_settings"]

    @property
    def update_settings(
        self,
    ) -> Callable[[logging_config.UpdateSettingsRequest], logging_config.Settings]:
        r"""Return a callable for the update settings method over gRPC.

        Updates the Log Router settings for the given resource.

        Note: Settings for the Log Router can currently only be
        configured for Google Cloud organizations. Once configured, it
        applies to all projects and folders in the Google Cloud
        organization.

        [UpdateSettings][google.logging.v2.ConfigServiceV2.UpdateSettings]
        will fail if 1) ``kms_key_name`` is invalid, or 2) the
        associated service account does not have the required
        ``roles/cloudkms.cryptoKeyEncrypterDecrypter`` role assigned for
        the key, or 3) access to the key is disabled. 4) ``location_id``
        is not supported by Logging. 5) ``location_id`` violate
        OrgPolicy.

        See `Enabling CMEK for Log
        Router <https://cloud.google.com/logging/docs/routing/managed-encryption>`__
        for more information.

        Returns:
            Callable[[~.UpdateSettingsRequest],
                    ~.Settings]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_settings" not in self._stubs:
            self._stubs["update_settings"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/UpdateSettings",
                request_serializer=logging_config.UpdateSettingsRequest.serialize,
                response_deserializer=logging_config.Settings.deserialize,
            )
        return self._stubs["update_settings"]

    @property
    def copy_log_entries(
        self,
    ) -> Callable[[logging_config.CopyLogEntriesRequest], operations_pb2.Operation]:
        r"""Return a callable for the copy log entries method over gRPC.

        Copies a set of log entries from a log bucket to a
        Cloud Storage bucket.

        Returns:
            Callable[[~.CopyLogEntriesRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "copy_log_entries" not in self._stubs:
            self._stubs["copy_log_entries"] = self._logged_channel.unary_unary(
                "/google.logging.v2.ConfigServiceV2/CopyLogEntries",
                request_serializer=logging_config.CopyLogEntriesRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["copy_log_entries"]

    def close(self):
        self._logged_channel.close()

    @property
    def cancel_operation(
        self,
    ) -> Callable[[operations_pb2.CancelOperationRequest], None]:
        r"""Return a callable for the cancel_operation method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "cancel_operation" not in self._stubs:
            self._stubs["cancel_operation"] = self._logged_channel.unary_unary(
                "/google.longrunning.Operations/CancelOperation",
                request_serializer=operations_pb2.CancelOperationRequest.SerializeToString,
                response_deserializer=None,
            )
        return self._stubs["cancel_operation"]

    @property
    def get_operation(
        self,
    ) -> Callable[[operations_pb2.GetOperationRequest], operations_pb2.Operation]:
        r"""Return a callable for the get_operation method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_operation" not in self._stubs:
            self._stubs["get_operation"] = self._logged_channel.unary_unary(
                "/google.longrunning.Operations/GetOperation",
                request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["get_operation"]

    @property
    def list_operations(
        self,
    ) -> Callable[
        [operations_pb2.ListOperationsRequest], operations_pb2.ListOperationsResponse
    ]:
        r"""Return a callable for the list_operations method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_operations" not in self._stubs:
            self._stubs["list_operations"] = self._logged_channel.unary_unary(
                "/google.longrunning.Operations/ListOperations",
                request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
                response_deserializer=operations_pb2.ListOperationsResponse.FromString,
            )
        return self._stubs["list_operations"]

    @property
    def kind(self) -> str:
        return "grpc"


__all__ = ("ConfigServiceV2GrpcTransport",)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.aiplatform.v1beta1.schema.predict.params",
    manifest={
        "ImageObjectDetectionPredictionParams",
    },
)


class ImageObjectDetectionPredictionParams(proto.Message):
    r"""Prediction model parameters for Image Object Detection.

    Attributes:
        confidence_threshold (float):
            The Model only returns predictions with at
            least this confidence score. Default value is
            0.0
        max_predictions (int):
            The Model only returns up to that many top,
            by confidence score, predictions per instance.
            Note that number of returned predictions is also
            limited by metadata's predictionsLimit. Default
            value is 10.
    """

    confidence_threshold: float = proto.Field(
        proto.FLOAT,
        number=1,
    )
    max_predictions: int = proto.Field(
        proto.INT32,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
